@@ -29,7 +29,6 @@
 #include <QScrollBar>
 
 #include <kcolorscheme.h>
-#include <kdirmodel.h>
 #include <kdirlister.h>
 #include <kfileitemdelegate.h>
 #include <klocale.h>
@@ -42,12 +41,12 @@
 #include <konq_operations.h>
 #include <kurl.h>
 
+#include "dolphinmodel.h"
 #include "dolphincolumnview.h"
 #include "dolphincontroller.h"
 #include "dolphinsortfilterproxymodel.h"
 #include "dolphindetailsview.h"
 #include "dolphiniconsview.h"
-#include "dolphinitemcategorizer.h"
 #include "renamedialog.h"
 #include "viewproperties.h"
 #include "dolphinsettings.h"
@@ -56,12 +55,12 @@
 DolphinView::DolphinView(QWidget* parent,
                          const KUrl& url,
                          KDirLister* dirLister,
-                         KDirModel* dirModel,
+                         DolphinModel* dolphinModel,
                          DolphinSortFilterProxyModel* proxyModel) :
     QWidget(parent),
     m_active(true),
     m_loadingDirectory(false),
-    m_initializeColumnView(false),
+    m_storedCategorizedSorting(false),
     m_mode(DolphinView::IconsView),
     m_topLayout(0),
     m_controller(0),
@@ -69,7 +68,7 @@ DolphinView::DolphinView(QWidget* parent,
     m_detailsView(0),
     m_columnView(0),
     m_fileItemDelegate(0),
-    m_dirModel(dirModel),
+    m_dolphinModel(dolphinModel),
     m_dirLister(dirLister),
     m_proxyModel(proxyModel)
 {
@@ -84,8 +83,8 @@ DolphinView::DolphinView(QWidget* parent,
 
     connect(m_dirLister, SIGNAL(completed()),
             this, SLOT(updateCutItems()));
-    connect(m_dirLister, SIGNAL(newItems(const QList<KFileItem>&)),
-            this, SLOT(generatePreviews(const QList<KFileItem>&)));
+    connect(m_dirLister, SIGNAL(newItems(const KFileItemList&)),
+            this, SLOT(generatePreviews(const KFileItemList&)));
 
     m_controller = new DolphinController(this);
     m_controller->setUrl(url);
@@ -93,18 +92,18 @@ DolphinView::DolphinView(QWidget* parent,
             this, SIGNAL(urlChanged(const KUrl&)));
     connect(m_controller, SIGNAL(requestContextMenu(const QPoint&)),
             this, SLOT(openContextMenu(const QPoint&)));
-    connect(m_controller, SIGNAL(urlsDropped(const KUrl::List&, const QModelIndex&, QWidget*)),
-            this, SLOT(dropUrls(const KUrl::List&, const QModelIndex&, QWidget*)));
+    connect(m_controller, SIGNAL(urlsDropped(const KUrl::List&, const KUrl&, const QModelIndex&, QWidget*)),
+            this, SLOT(dropUrls(const KUrl::List&, const KUrl&, const QModelIndex&, QWidget*)));
     connect(m_controller, SIGNAL(sortingChanged(DolphinView::Sorting)),
             this, SLOT(updateSorting(DolphinView::Sorting)));
     connect(m_controller, SIGNAL(sortOrderChanged(Qt::SortOrder)),
             this, SLOT(updateSortOrder(Qt::SortOrder)));
-    connect(m_controller, SIGNAL(itemTriggered(const QModelIndex&)),
-            this, SLOT(triggerItem(const QModelIndex&)));
+    connect(m_controller, SIGNAL(itemTriggered(const KFileItem&)),
+            this, SLOT(triggerItem(const KFileItem&)));
     connect(m_controller, SIGNAL(activated()),
             this, SLOT(activate()));
-    connect(m_controller, SIGNAL(itemEntered(const QModelIndex&)),
-            this, SLOT(showHoverInformation(const QModelIndex&)));
+    connect(m_controller, SIGNAL(itemEntered(const KFileItem&)),
+            this, SLOT(showHoverInformation(const KFileItem&)));
     connect(m_controller, SIGNAL(viewportEntered()),
             this, SLOT(clearHoverInformation()));
 
@@ -123,7 +122,7 @@ const KUrl& DolphinView::url() const
 
 KUrl DolphinView::rootUrl() const
 {
-    return isColumnViewActive() ? m_dirLister->url() : url();
+    return isColumnViewActive() ? m_columnView->rootUrl() : url();
 }
 
 void DolphinView::setActive(bool active)
@@ -134,12 +133,29 @@ void DolphinView::setActive(bool active)
 
     m_active = active;
 
-    updateViewportColor();
+    QColor color = KColorScheme(QPalette::Active, KColorScheme::View).background().color();
+    if (active) {
+        // TODO: emitting urlChanged() is a hack, as the URL hasn't really changed. It
+        // bypasses the problem when having a split view and changing the active view to
+        // update the some URL dependent states. A nicer approach should be no big deal...
+        emit urlChanged(url());
+        emit selectionChanged(selectedItems());
+    } else {
+        color.setAlpha(150);
+    }
+
+    QWidget* viewport = itemView()->viewport();
+    QPalette palette;
+    palette.setColor(viewport->backgroundRole(), color);
+    viewport->setPalette(palette);
+
     update();
 
     if (active) {
         emit activated();
     }
+
+    m_controller->indicateActivationChange(active);
 }
 
 bool DolphinView::isActive() const
@@ -160,8 +176,9 @@ void DolphinView::setMode(Mode mode)
         // to go back to the root URL of the column view automatically.
         // Otherwise there it would not be possible to turn off the column view
         // without focusing the first column.
-        setUrl(m_dirLister->url());
-        m_controller->setUrl(m_dirLister->url());
+        const KUrl root = rootUrl();
+        setUrl(root);
+        m_controller->setUrl(root);
     }
 
     const KUrl viewPropsUrl = viewPropertiesUrl();
@@ -169,7 +186,19 @@ void DolphinView::setMode(Mode mode)
     props.setViewMode(m_mode);
 
     createView();
-    startDirLister(viewPropsUrl);
+
+    // Not all view modes support categorized sorting. Adjust the sorting model
+    // if changing the view mode results in a change of the categorized sorting
+    // capabilities.
+    m_storedCategorizedSorting = props.categorizedSorting();
+    const bool categorized = m_storedCategorizedSorting && supportsCategorizedSorting();
+    if (categorized != m_proxyModel->isCategorizedModel()) {
+        m_proxyModel->setCategorizedModel(categorized);
+        m_proxyModel->sort(m_proxyModel->sortColumn(), m_proxyModel->sortOrder());
+        emit categorizedSortingChanged();
+    }
+
+    loadDirectory(viewPropsUrl);
 
     emit modeChanged();
 }
@@ -188,7 +217,7 @@ void DolphinView::setShowPreview(bool show)
     m_controller->setShowPreview(show);
     emit showPreviewChanged();
 
-    startDirLister(viewPropsUrl, true);
+    loadDirectory(viewPropsUrl, true);
 }
 
 bool DolphinView::showPreview() const
@@ -207,9 +236,10 @@ void DolphinView::setShowHiddenFiles(bool show)
     props.setShowHiddenFiles(show);
 
     m_dirLister->setShowingDotFiles(show);
+    m_controller->setShowHiddenFiles(show);
     emit showHiddenFilesChanged();
 
-    startDirLister(viewPropsUrl, true);
+    loadDirectory(viewPropsUrl, true);
 }
 
 bool DolphinView::showHiddenFiles() const
@@ -219,35 +249,35 @@ bool DolphinView::showHiddenFiles() const
 
 void DolphinView::setCategorizedSorting(bool categorized)
 {
-    if (!supportsCategorizedSorting() || (categorized == categorizedSorting())) {
+    if (categorized == categorizedSorting()) {
         return;
     }
 
-    Q_ASSERT(m_iconsView != 0);
-    if (categorized) {
-        Q_ASSERT(m_iconsView->itemCategorizer() == 0);
-        m_iconsView->setItemCategorizer(new DolphinItemCategorizer());
-    } else {
-        KItemCategorizer* categorizer = m_iconsView->itemCategorizer();
-        m_iconsView->setItemCategorizer(0);
-        delete categorizer;
-    }
+    // setCategorizedSorting(true) may only get invoked
+    // if the view supports categorized sorting
+    Q_ASSERT(!categorized || supportsCategorizedSorting());
 
     ViewProperties props(viewPropertiesUrl());
     props.setCategorizedSorting(categorized);
     props.save();
 
+    m_storedCategorizedSorting = categorized;
+    m_proxyModel->setCategorizedModel(categorized);
+    m_proxyModel->sort(m_proxyModel->sortColumn(), m_proxyModel->sortOrder());
+
     emit categorizedSortingChanged();
 }
 
 bool DolphinView::categorizedSorting() const
 {
-    if (!supportsCategorizedSorting()) {
-        return false;
-    }
-
-    Q_ASSERT(m_iconsView != 0);
-    return m_iconsView->itemCategorizer() != 0;
+    // If all view modes would support categorized sorting, returning
+    // m_proxyModel->isCategorizedModel() would be the way to go. As
+    // currently only the icons view supports caterized sorting, we remember
+    // the stored view properties state in m_storedCategorizedSorting and
+    // return this state. The application takes care to disable the corresponding
+    // checkbox by checking DolphinView::supportsCategorizedSorting() to indicate
+    // that this setting is not applied to the current view mode.
+    return m_storedCategorizedSorting;
 }
 
 bool DolphinView::supportsCategorizedSorting() const
@@ -263,9 +293,11 @@ void DolphinView::selectAll()
 void DolphinView::invertSelection()
 {
     if (isColumnViewActive()) {
-        // In opposite to QAbstractItemView::selectAll() there is no virtual method
-        // for adjusting the invertion of a selection. As the generic approach by using
-        // the selection model does not work for the column view, we delegate this task:
+        // QAbstractItemView does not offer a virtual method invertSelection()
+        // as counterpart to QAbstractItemView::selectAll(). This makes it
+        // necessary to delegate the inverting of the selection to the
+        // column view, as only the selection of the active column should
+        // get inverted.
         m_columnView->invertSelection();
     } else {
         QItemSelectionModel* selectionModel = itemView()->selectionModel();
@@ -275,7 +307,7 @@ void DolphinView::invertSelection()
         const QModelIndex bottomRight = itemModel->index(itemModel->rowCount() - 1,
                                                          itemModel->columnCount() - 1);
 
-        QItemSelection selection(topLeft, bottomRight);
+        const QItemSelection selection(topLeft, bottomRight);
         selectionModel->select(selection, QItemSelectionModel::Toggle);
     }
 }
@@ -290,23 +322,20 @@ void DolphinView::clearSelection()
     itemView()->selectionModel()->clear();
 }
 
-QList<KFileItem> DolphinView::selectedItems() const
+KFileItemList DolphinView::selectedItems() const
 {
     const QAbstractItemView* view = itemView();
 
-    // Our view has a selection, we will map them back to the DirModel
+    // Our view has a selection, we will map them back to the DolphinModel
     // and then fill the KFileItemList.
     Q_ASSERT((view != 0) && (view->selectionModel() != 0));
 
     const QItemSelection selection = m_proxyModel->mapSelectionToSource(view->selectionModel()->selection());
-    QList<KFileItem> itemList;
+    KFileItemList itemList;
 
     const QModelIndexList indexList = selection.indexes();
-    QModelIndexList::const_iterator end = indexList.end();
-    for (QModelIndexList::const_iterator it = indexList.begin(); it != end; ++it) {
-        Q_ASSERT((*it).isValid());
-
-        KFileItem item = m_dirModel->itemForIndex(*it);
+    foreach (QModelIndex index, indexList) {
+        KFileItem item = m_dolphinModel->itemForIndex(index);
         if (!item.isNull()) {
             itemList.append(item);
         }
@@ -318,24 +347,27 @@ QList<KFileItem> DolphinView::selectedItems() const
 KUrl::List DolphinView::selectedUrls() const
 {
     KUrl::List urls;
-    const QList<KFileItem> list = selectedItems();
-    for ( QList<KFileItem>::const_iterator it = list.begin(), end = list.end();
-          it != end; ++it ) {
-        urls.append((*it).url());
+    const KFileItemList list = selectedItems();
+    foreach (KFileItem item, list) {
+        urls.append(item.url());
     }
     return urls;
 }
 
 KFileItem DolphinView::fileItem(const QModelIndex& index) const
 {
-    const QModelIndex dirModelIndex = m_proxyModel->mapToSource(index);
-    return m_dirModel->itemForIndex(dirModelIndex);
+    const QModelIndex dolphinModelIndex = m_proxyModel->mapToSource(index);
+    return m_dolphinModel->itemForIndex(dolphinModelIndex);
 }
 
 void DolphinView::setContentsPosition(int x, int y)
 {
     QAbstractItemView* view = itemView();
-    view->horizontalScrollBar()->setValue(x);
+
+    // the ColumnView takes care itself for the horizontal scrolling
+    if (!isColumnViewActive()) {
+        view->horizontalScrollBar()->setValue(x);
+    }
     view->verticalScrollBar()->setValue(y);
 
     m_loadingDirectory = false;
@@ -392,65 +424,91 @@ Qt::SortOrder DolphinView::sortOrder() const
     return m_proxyModel->sortOrder();
 }
 
-void DolphinView::setAdditionalInfo(KFileItemDelegate::AdditionalInformation info)
+void DolphinView::setAdditionalInfo(KFileItemDelegate::InformationList info)
 {
     const KUrl viewPropsUrl = viewPropertiesUrl();
     ViewProperties props(viewPropsUrl);
     props.setAdditionalInfo(info);
 
-    m_controller->setShowAdditionalInfo(info != KFileItemDelegate::NoInformation);
-    m_fileItemDelegate->setAdditionalInformation(info);
+    m_controller->setAdditionalInfoCount(info.count());
+    m_fileItemDelegate->setShowInformation(info);
 
     emit additionalInfoChanged(info);
-    startDirLister(viewPropsUrl, true);
+    loadDirectory(viewPropsUrl, true);
 }
 
-KFileItemDelegate::AdditionalInformation DolphinView::additionalInfo() const
+KFileItemDelegate::InformationList DolphinView::additionalInfo() const
 {
-    return m_fileItemDelegate->additionalInformation();
+    return m_fileItemDelegate->showInformation();
 }
 
 void DolphinView::reload()
 {
     setUrl(url());
-    startDirLister(url(), true);
+    loadDirectory(url(), true);
 }
 
 void DolphinView::refresh()
 {
+    const bool oldActivationState = m_active;
+    m_active = true;
+
     createView();
     applyViewProperties(m_controller->url());
     reload();
-    updateViewportColor();
+
+    setActive(oldActivationState);
 }
 
-void DolphinView::setUrl(const KUrl& url)
+void DolphinView::updateView(const KUrl& url, const KUrl& rootUrl)
 {
     if (m_controller->url() == url) {
         return;
     }
 
+    const bool restoreColumnView =  !rootUrl.isEmpty()
+                                    && !rootUrl.equals(url, KUrl::CompareWithoutTrailingSlash)
+                                    && rootUrl.isParentOf(url);
+
     m_controller->setUrl(url); // emits urlChanged, which we forward
 
-    applyViewProperties(url);
+    if (restoreColumnView) {
+        applyViewProperties(rootUrl);
+        loadDirectory(rootUrl);
+        // Restoring the column view relies on the URL-history. It might be possible
+        // that the view properties have been changed or deleted in the meantime, so
+        // it cannot be asserted that really a column view has been created:
+        if (itemView() == m_columnView) {
+            m_columnView->setRootUrl(rootUrl);
+            m_columnView->showColumn(url);
+        }
+    } else {
+        applyViewProperties(url);
+        loadDirectory(url);
+    }
 
-    startDirLister(url);
+    itemView()->setFocus();
+
+    emit startedPathLoading(url);
+}
+
+void DolphinView::setUrl(const KUrl& url)
+{
+    updateView(url, KUrl());
 }
 
 void DolphinView::mouseReleaseEvent(QMouseEvent* event)
 {
     QWidget::mouseReleaseEvent(event);
-    setActive(true);;
+    setActive(true);
 }
 void DolphinView::activate()
 {
     setActive(true);
 }
 
-void DolphinView::triggerItem(const QModelIndex& index)
+void DolphinView::triggerItem(const KFileItem& item)
 {
-    Q_ASSERT(index.isValid());
-
     const Qt::KeyboardModifiers modifier = QApplication::keyboardModifiers();
     if ((modifier & Qt::ShiftModifier) || (modifier & Qt::ControlModifier)) {
         // items are selected by the user, hence don't trigger the
@@ -458,7 +516,6 @@ void DolphinView::triggerItem(const QModelIndex& index)
         return;
     }
 
-    const KFileItem item = m_dirModel->itemForIndex(m_proxyModel->mapToSource(index));
     if (item.isNull()) {
         return;
     }
@@ -466,7 +523,7 @@ void DolphinView::triggerItem(const QModelIndex& index)
     emit itemTriggered(item); // caught by DolphinViewContainer or DolphinPart
 }
 
-void DolphinView::generatePreviews(const QList<KFileItem>& items)
+void DolphinView::generatePreviews(const KFileItemList& items)
 {
     if (m_controller->showPreview()) {
         KIO::PreviewJob* job = KIO::filePreview(items, 128);
@@ -484,15 +541,15 @@ void DolphinView::showPreview(const KFileItem& item, const QPixmap& pixmap)
         return;
     }
 
-    const QModelIndex idx = m_dirModel->indexForItem(item);
+    const QModelIndex idx = m_dolphinModel->indexForItem(item);
     if (idx.isValid() && (idx.column() == 0)) {
         const QMimeData* mimeData = QApplication::clipboard()->mimeData();
         if (KonqMimeData::decodeIsCutSelection(mimeData) && isCutItem(item)) {
             KIconEffect iconEffect;
-            const QPixmap cutPixmap = iconEffect.apply(pixmap, K3Icon::Desktop, K3Icon::DisabledState);
-            m_dirModel->setData(idx, QIcon(cutPixmap), Qt::DecorationRole);
+            const QPixmap cutPixmap = iconEffect.apply(pixmap, KIconLoader::Desktop, KIconLoader::DisabledState);
+            m_dolphinModel->setData(idx, QIcon(cutPixmap), Qt::DecorationRole);
         } else {
-            m_dirModel->setData(idx, QIcon(pixmap), Qt::DecorationRole);
+            m_dolphinModel->setData(idx, QIcon(pixmap), Qt::DecorationRole);
         }
     }
 }
@@ -502,7 +559,7 @@ void DolphinView::emitSelectionChangedSignal()
     emit selectionChanged(DolphinView::selectedItems());
 }
 
-void DolphinView::startDirLister(const KUrl& url, bool reload)
+void DolphinView::loadDirectory(const KUrl& url, bool reload)
 {
     if (!url.isValid()) {
         const QString location(url.pathOrUrl());
@@ -518,43 +575,17 @@ void DolphinView::startDirLister(const KUrl& url, bool reload)
     m_loadingDirectory = true;
 
     m_dirLister->stop();
+    m_dirLister->openUrl(url, reload ? KDirLister::Reload : KDirLister::NoFlags);
 
-    bool openDir = true;
-    bool keepOldDirs = isColumnViewActive() && !m_initializeColumnView;
-    m_initializeColumnView = false;
-
-    if (keepOldDirs) {
+    if (isColumnViewActive()) {
+        // adjusting the directory lister is not enough in the case of the
+        // column view, as each column has its own directory lister internally...
         if (reload) {
-            keepOldDirs = false;
-
-            const KUrl& dirListerUrl = m_dirLister->url();
-            if (dirListerUrl.isValid()) {
-                const KUrl::List dirs = m_dirLister->directories();
-                KUrl url;
-                foreach(url, dirs) {
-                    m_dirLister->updateDirectory(url);
-                }
-                openDir = false;
-            }
-        } else if (m_dirLister->directories().contains(url)) {
-            // The dir lister contains the directory already, so
-            // KDirLister::openUrl() may not been invoked twice.
-            m_dirLister->updateDirectory(url);
-            openDir = false;
+            m_columnView->reload();
         } else {
-            const KUrl& dirListerUrl = m_dirLister->url();
-            if ((dirListerUrl == url) || !m_dirLister->url().isParentOf(url)) {
-                // The current URL is not a child of the dir lister
-                // URL. This may happen when e. g. a place has been selected
-                // and hence the view must be reset.
-                keepOldDirs = false;
-            }
+            m_columnView->showColumn(url);
         }
     }
-
-    if (openDir) {
-        m_dirLister->openUrl(url, keepOldDirs, reload);
-    }
 }
 
 KUrl DolphinView::viewPropertiesUrl() const
@@ -568,7 +599,7 @@ KUrl DolphinView::viewPropertiesUrl() const
 
 void DolphinView::applyViewProperties(const KUrl& url)
 {
-    if (isColumnViewActive() && m_dirLister->url().isParentOf(url)) {
+    if (isColumnViewActive() && rootUrl().isParentOf(url)) {
         // The column view is active, hence don't apply the view properties
         // of sub directories (represented by columns) to the view. The
         // view always represents the properties of the first column.
@@ -582,14 +613,6 @@ void DolphinView::applyViewProperties(const KUrl& url)
         m_mode = mode;
         createView();
         emit modeChanged();
-
-        if (m_mode == ColumnView) {
-            // The mode has been changed to the Column View. When starting the dir
-            // lister with DolphinView::startDirLister() it is important to give a
-            // hint that the dir lister may not keep the current directory
-            // although this is the default for showing a hierarchy.
-            m_initializeColumnView = true;
-        }
     }
     if (itemView() == 0) {
         createView();
@@ -600,22 +623,15 @@ void DolphinView::applyViewProperties(const KUrl& url)
     const bool showHiddenFiles = props.showHiddenFiles();
     if (showHiddenFiles != m_dirLister->showingDotFiles()) {
         m_dirLister->setShowingDotFiles(showHiddenFiles);
+        m_controller->setShowHiddenFiles(showHiddenFiles);
         emit showHiddenFilesChanged();
     }
 
-    const bool categorized = props.categorizedSorting();
-    if (categorized != categorizedSorting()) {
-        if (supportsCategorizedSorting()) {
-            Q_ASSERT(m_iconsView != 0);
-            if (categorized) {
-                Q_ASSERT(m_iconsView->itemCategorizer() == 0);
-                m_iconsView->setItemCategorizer(new DolphinItemCategorizer());
-            } else {
-                KItemCategorizer* categorizer = m_iconsView->itemCategorizer();
-                m_iconsView->setItemCategorizer(0);
-                delete categorizer;
-            }
-        }
+    m_storedCategorizedSorting = props.categorizedSorting();
+    const bool categorized = m_storedCategorizedSorting && supportsCategorizedSorting();
+    if (categorized != m_proxyModel->isCategorizedModel()) {
+        m_proxyModel->setCategorizedModel(categorized);
+        m_proxyModel->sort(m_proxyModel->sortColumn(), m_proxyModel->sortOrder());
         emit categorizedSortingChanged();
     }
 
@@ -631,10 +647,10 @@ void DolphinView::applyViewProperties(const KUrl& url)
         emit sortOrderChanged(sortOrder);
     }
 
-    KFileItemDelegate::AdditionalInformation info = props.additionalInfo();
-    if (info != m_fileItemDelegate->additionalInformation()) {
-        m_controller->setShowAdditionalInfo(info != KFileItemDelegate::NoInformation);
-        m_fileItemDelegate->setAdditionalInformation(info);
+    KFileItemDelegate::InformationList info = props.additionalInfo();
+    if (info != m_fileItemDelegate->showInformation()) {
+        m_controller->setAdditionalInfoCount(info.count());
+        m_fileItemDelegate->setShowInformation(info);
         emit additionalInfoChanged(info);
     }
 
@@ -645,7 +661,7 @@ void DolphinView::applyViewProperties(const KUrl& url)
     }
 }
 
-void DolphinView::changeSelection(const QList<KFileItem>& selection)
+void DolphinView::changeSelection(const KFileItemList& selection)
 {
     clearSelection();
     if (selection.isEmpty()) {
@@ -657,7 +673,7 @@ void DolphinView::changeSelection(const QList<KFileItem>& selection)
     foreach(const KFileItem& item, selection) {
         url = item.url().upUrl();
         if (baseUrl.equals(url, KUrl::CompareWithoutTrailingSlash)) {
-            QModelIndex index = m_proxyModel->mapFromSource(m_dirModel->indexForItem(item));
+            QModelIndex index = m_proxyModel->mapFromSource(m_dolphinModel->indexForItem(item));
             new_selection.select(index, index);
         }
     }
@@ -679,12 +695,13 @@ void DolphinView::openContextMenu(const QPoint& pos)
 }
 
 void DolphinView::dropUrls(const KUrl::List& urls,
-                           const QModelIndex& index,
+                           const KUrl& destPath,
+                           const QModelIndex& destIndex,
                            QWidget* source)
 {
     KFileItem directory;
-    if (isValidNameIndex(index)) {
-        KFileItem item = fileItem(index);
+    if (isValidNameIndex(destIndex)) {
+        KFileItem item = fileItem(destIndex);
         Q_ASSERT(!item.isNull());
         if (item.isDir()) {
             // the URLs are dropped above a directory
@@ -699,7 +716,7 @@ void DolphinView::dropUrls(const KUrl::List& urls,
     }
 
     const KUrl& destination = (directory.isNull()) ?
-                              url() : directory.url();
+                              destPath : directory.url();
     dropUrls(urls, destination);
 }
 
@@ -749,9 +766,9 @@ void DolphinView::updateCutItems()
     QList<CutItem>::const_iterator it = m_cutItemsCache.begin();
     QList<CutItem>::const_iterator end = m_cutItemsCache.end();
     while (it != end) {
-        const QModelIndex index = m_dirModel->indexForUrl((*it).url);
+        const QModelIndex index = m_dolphinModel->indexForUrl((*it).url);
         if (index.isValid()) {
-            m_dirModel->setData(index, QIcon((*it).pixmap), Qt::DecorationRole);
+            m_dolphinModel->setData(index, QIcon((*it).pixmap), Qt::DecorationRole);
         }
         ++it;
     }
@@ -761,16 +778,13 @@ void DolphinView::updateCutItems()
     applyCutItemEffect();
 }
 
-void DolphinView::showHoverInformation(const QModelIndex& index)
+void DolphinView::showHoverInformation(const KFileItem& item)
 {
     if (hasSelection()) {
         return;
     }
 
-    const KFileItem item = fileItem(index);
-    if (!item.isNull()) {
-        emit requestItemInfo(item);
-    }
+    emit requestItemInfo(item);
 }
 
 void DolphinView::clearHoverInformation()
@@ -781,16 +795,16 @@ void DolphinView::clearHoverInformation()
 
 void DolphinView::createView()
 {
+    KFileItemDelegate::InformationList infoList;
+    if (m_fileItemDelegate != 0) {
+        infoList = m_fileItemDelegate->showInformation();
+    }
+
     // delete current view
     QAbstractItemView* view = itemView();
     if (view != 0) {
         m_topLayout->removeWidget(view);
         view->close();
-        if (view == m_iconsView) {
-            KItemCategorizer* categorizer = m_iconsView->itemCategorizer();
-            m_iconsView->setItemCategorizer(0);
-            delete categorizer;
-        }
         view->deleteLater();
         view = 0;
         m_iconsView = 0;
@@ -805,10 +819,11 @@ void DolphinView::createView()
 
     // ... and recreate it representing the current mode
     switch (m_mode) {
-    case IconsView:
+    case IconsView: {
         m_iconsView = new DolphinIconsView(this, m_controller);
         view = m_iconsView;
         break;
+    }
 
     case DetailsView:
         m_detailsView = new DolphinDetailsView(this, m_controller);
@@ -824,12 +839,13 @@ void DolphinView::createView()
     Q_ASSERT(view != 0);
 
     m_fileItemDelegate = new KFileItemDelegate(view);
+    m_fileItemDelegate->setShowInformation(infoList);
     view->setItemDelegate(m_fileItemDelegate);
 
     view->setModel(m_proxyModel);
     view->setSelectionMode(QAbstractItemView::ExtendedSelection);
 
-    new KMimeTypeResolver(view, m_dirModel);
+    new KMimeTypeResolver(view, m_dolphinModel);
     m_topLayout->insertWidget(1, view);
 
     connect(view->selectionModel(), SIGNAL(selectionChanged(const QItemSelection&, const QItemSelection&)),
@@ -838,6 +854,7 @@ void DolphinView::createView()
             this, SLOT(emitContentsMoved()));
     connect(view->horizontalScrollBar(), SIGNAL(valueChanged(int)),
             this, SLOT(emitContentsMoved()));
+    view->setFocus();
 }
 
 QAbstractItemView* DolphinView::itemView() const
@@ -853,7 +870,7 @@ QAbstractItemView* DolphinView::itemView() const
 
 bool DolphinView::isValidNameIndex(const QModelIndex& index) const
 {
-    return index.isValid() && (index.column() == KDirModel::Name);
+    return index.isValid() && (index.column() == DolphinModel::Name);
 }
 
 bool DolphinView::isCutItem(const KFileItem& item) const
@@ -885,12 +902,10 @@ void DolphinView::applyCutItemEffect()
     KFileItemList::const_iterator it = items.begin();
     const KFileItemList::const_iterator end = items.end();
     while (it != end) {
-        KFileItem* item = *it;
-        if (isCutItem(*item)) {
-            const QModelIndex index = m_dirModel->indexForItem(*item);
-            // Huh? the item is already known
-            //const KFileItem item = m_dirModel->itemForIndex(index);
-            const QVariant value = m_dirModel->data(index, Qt::DecorationRole);
+        const KFileItem item = *it;
+        if (isCutItem(item)) {
+            const QModelIndex index = m_dolphinModel->indexForItem(item);
+            const QVariant value = m_dolphinModel->data(index, Qt::DecorationRole);
             if (value.type() == QVariant::Icon) {
                 const QIcon icon(qvariant_cast<QIcon>(value));
                 QPixmap pixmap = icon.pixmap(128, 128);
@@ -898,34 +913,18 @@ void DolphinView::applyCutItemEffect()
                 // remember current pixmap for the item to be able
                 // to restore it when other items get cut
                 CutItem cutItem;
-                cutItem.url = item->url();
+                cutItem.url = item.url();
                 cutItem.pixmap = pixmap;
                 m_cutItemsCache.append(cutItem);
 
                 // apply icon effect to the cut item
                 KIconEffect iconEffect;
-                pixmap = iconEffect.apply(pixmap, K3Icon::Desktop, K3Icon::DisabledState);
-                m_dirModel->setData(index, QIcon(pixmap), Qt::DecorationRole);
+                pixmap = iconEffect.apply(pixmap, KIconLoader::Desktop, KIconLoader::DisabledState);
+                m_dolphinModel->setData(index, QIcon(pixmap), Qt::DecorationRole);
             }
         }
         ++it;
     }
 }
 
-void DolphinView::updateViewportColor()
-{
-    QColor color = KColorScheme(KColorScheme::View).background();
-    if (m_active) {
-        emit urlChanged(url()); // Hmm, this is a hack; the url hasn't really changed.
-        emit selectionChanged(selectedItems());
-    } else {
-        color.setAlpha(0);
-    }
-
-    QWidget* viewport = itemView()->viewport();
-    QPalette palette;
-    palette.setColor(viewport->backgroundRole(), color);
-    viewport->setPalette(palette);
-}
-
 #include "dolphinview.moc"
