@@ -41,7 +41,7 @@ class DolphinController;
 class KDirLister;
 class KFileItemDelegate;
 class KUrl;
-class KDirModel;
+class DolphinModel;
 class DolphinColumnView;
 class DolphinDetailsView;
 class DolphinIconsView;
@@ -116,7 +116,7 @@ public:
      * @param url             Specifies the content which should be shown.
      * @param dirLister       Used directory lister. The lister is not owned
      *                        by the view and won't get deleted.
-     * @param dirModel        Used directory model. The model is not owned
+     * @param dolphinModel    Used directory model. The model is not owned
      *                        by the view and won't get deleted.
      * @param proxyModel      Used proxy model which specifies the sorting. The
      *                        model is not owned by the view and won't get
@@ -125,7 +125,7 @@ public:
     DolphinView(QWidget* parent,
                 const KUrl& url,
                 KDirLister* dirLister,
-                KDirModel* dirModel,
+                DolphinModel* dolphinModel,
                 DolphinSortFilterProxyModel* proxyModel);
 
     virtual ~DolphinView();
@@ -224,7 +224,7 @@ public:
      * selected.
      * @see DolphinView::selectedUrls()
      */
-    QList<KFileItem> selectedItems() const;
+    KFileItemList selectedItems() const;
 
     /**
      * Returns a list of URLs for all selected items. An empty list
@@ -279,21 +279,31 @@ public:
     Qt::SortOrder sortOrder() const;
 
     /** Sets the additional information which should be shown for the items. */
-    void setAdditionalInfo(KFileItemDelegate::AdditionalInformation info);
+    void setAdditionalInfo(KFileItemDelegate::InformationList info);
 
     /** Returns the additional information which should be shown for the items. */
-    KFileItemDelegate::AdditionalInformation additionalInfo() const;
+    KFileItemDelegate::InformationList additionalInfo() const;
 
     /** Reloads the current directory. */
     void reload();
 
     /**
-     * Refreshs the view to get synchronized with the (updated) Dolphin settings.
+     * Refreshes the view to get synchronized with the (updated) Dolphin settings.
      * This method only needs to get invoked if the view settings for the Icons View,
      * Details View or Columns View have been changed.
      */
     void refresh();
 
+    /**
+     * Changes the directory of the view to \a url. If \a rootUrl is empty, the view
+     * properties from \a url are used for adjusting the view mode and the other properties.
+     * If \a rootUrl is not empty, the view properties from the root URL are considered
+     * instead. Specifying a root URL is only required if a view having a different root URL
+     * (e. g. the column view) should be restored. Usually using DolphinView::setUrl()
+     * is enough for changing the current URL.
+     */
+    void updateView(const KUrl& url, const KUrl& rootUrl);
+
 public slots:
     /**
      * Changes the directory to \a url. If the current directory is equal to
@@ -307,7 +317,7 @@ public slots:
      * will actually get selected. The view will e.g. not select items which
      * are not in the currently displayed folder.
      */
-    void changeSelection(const QList<KFileItem>& selection);
+    void changeSelection(const KFileItemList& selection);
 
 signals:
     /**
@@ -345,7 +355,7 @@ signals:
     void sortOrderChanged(Qt::SortOrder order);
 
     /** Is emitted if the additional information for an item has been changed. */
-    void additionalInfoChanged(KFileItemDelegate::AdditionalInformation info);
+    void additionalInfoChanged(KFileItemDelegate::InformationList info);
 
     /**
      * Is emitted if information of an item is requested to be shown e. g. in the sidebar.
@@ -359,7 +369,7 @@ signals:
     /**
      * Is emitted whenever the selection has been changed.
      */
-    void selectionChanged(const QList<KFileItem>& selection);
+    void selectionChanged(const KFileItemList& selection);
 
     /**
      * Is emitted if a context menu is requested for the item \a item,
@@ -388,6 +398,14 @@ signals:
      */
     void errorMessage(const QString& msg);
 
+    /**
+     * Is emitted after DolphinView::setUrl() has been invoked and
+     * the path \a url is currently loaded. If this signal is emitted,
+     * it is assured that the view contains already the correct root
+     * URL and property settings.
+     */
+    void startedPathLoading(const KUrl& url);
+
 protected:
     /** @see QWidget::mouseReleaseEvent */
     virtual void mouseReleaseEvent(QMouseEvent* event);
@@ -400,18 +418,18 @@ private slots:
     void activate();
 
     /**
-     * If the item specified by \a index is a directory, then this
+     * If the item \a item is a directory, then this
      * directory will be loaded. If the  item is a file, the corresponding
      * application will get started.
      */
-    void triggerItem(const QModelIndex& index);
+    void triggerItem(const KFileItem& index);
 
     /**
      * Generates a preview image for each file item in \a items.
      * The current preview settings (maximum size, 'Show Preview' menu)
      * are respected.
      */
-    void generatePreviews(const QList<KFileItem>& items);
+    void generatePreviews(const KFileItemList& items);
 
     /**
      * Replaces the icon of the item \a item by the preview pixmap
@@ -429,11 +447,14 @@ private slots:
     void openContextMenu(const QPoint& pos);
 
     /**
-     * Drops the URLs \a urls to the index \a index. \a source
+     * Drops the URLs \a urls to the destination path \a destPath. If
+     * the URLs are dropped above an item inside the destination path,
+     * the item is indicated by \a destIndex. \a source
      * indicates the widget where the dragging has been started from.
      */
     void dropUrls(const KUrl::List& urls,
-                  const QModelIndex& index,
+                  const KUrl& destPath,
+                  const QModelIndex& destIndex,
                   QWidget* source);
 
     /**
@@ -465,11 +486,11 @@ private slots:
 
     /**
      * Updates the status bar to show hover information for the
-     * item with the index \a index. If currently other items are selected,
+     * item \a item. If currently other items are selected,
      * no hover information is shown.
      * @see DolphinView::clearHoverInformation()
      */
-    void showHoverInformation(const QModelIndex& index);
+    void showHoverInformation(const KFileItem& item);
 
     /**
      * Clears the hover information shown in the status bar.
@@ -478,7 +499,7 @@ private slots:
     void clearHoverInformation();
 
 private:
-    void startDirLister(const KUrl& url, bool reload = false);
+    void loadDirectory(const KUrl& url, bool reload = false);
 
     /**
      * Returns the URL where the view properties should be stored. Usually
@@ -509,7 +530,7 @@ private:
 
     /**
      * Returns true if the index is valid and represents
-     * the column KDirModel::Name.
+     * the column DolphinModel::Name.
      */
     bool isValidNameIndex(const QModelIndex& index) const;
 
@@ -522,12 +543,6 @@ private:
     /** Applies an item effect to all cut items. */
     void applyCutItemEffect();
 
-    /**
-     * Updates the color of the viewport depending from the
-     * activation state (see DolphinView::isActive()).
-     */
-    void updateViewportColor();
-
     /**
      * Returns true, if the ColumnView is activated. As the column view
      * requires some special handling for iterating through directories,
@@ -551,7 +566,7 @@ private:
 
     bool m_active;
     bool m_loadingDirectory;
-    bool m_initializeColumnView;
+    bool m_storedCategorizedSorting;
     Mode m_mode;
 
     DolphinMainWindow* m_mainWindow;
@@ -563,11 +578,13 @@ private:
     DolphinColumnView* m_columnView;
     KFileItemDelegate* m_fileItemDelegate;
 
-    KDirModel* m_dirModel;
+    DolphinModel* m_dolphinModel;
     KDirLister* m_dirLister;
     DolphinSortFilterProxyModel* m_proxyModel;
 
     QList<CutItem> m_cutItemsCache;
+
+    KUrl m_rootUrl;
 };
 
 #endif // DOLPHINVIEW_H
