@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: passwd.h 679363 2007-06-23 18:53:52Z whiting $
+ * $Id: passwd.h 720106 2007-10-02 12:12:47Z ogoffart $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -17,7 +17,7 @@
  */
 
 class PasswdProcess
-    : public PtyProcess
+    : public KDESu::PtyProcess
 {
 public:
     PasswdProcess(const QByteArray &user = QByteArray());
