@@ -55,7 +55,7 @@
 #include <ktoggleaction.h>
 
 #include <kparts/part.h>
-#include <kparts/componentfactory.h>
+#include <kservicetypetrader.h>
 
 #include <kbookmark.h>
 #include <kbookmarkmanager.h>
@@ -192,58 +192,67 @@ void KEBApp::createActions() {
     connect(actnCancelFavIconUpdates, SIGNAL( triggered() ), actn, SLOT( slotCancelFavIconUpdates() ));
 
     QAction* actnImportNS = actionCollection()->addAction("importNS");
+    actnImportNS->setObjectName("NS");
     actnImportNS->setIcon(KIcon("netscape"));
     actnImportNS->setText(i18n("Import &Netscape Bookmarks..."));
     connect(actnImportNS, SIGNAL( triggered() ), actn, SLOT( slotImport() ));
 
     QAction* actnImportOpera = actionCollection()->addAction("importOpera");
+    actnImportOpera->setObjectName("Opera");
     actnImportOpera->setIcon(KIcon("opera"));
     actnImportOpera->setText(i18n("Import &Opera Bookmarks..."));
     connect(actnImportOpera, SIGNAL( triggered() ), actn, SLOT( slotImport() ));
 
     QAction* actnImportCrashes = actionCollection()->addAction("importCrashes");
+    actnImportCrashes->setObjectName("Crashes");
     actnImportCrashes->setText(i18n("Import All &Crash Sessions as Bookmarks..."));
     connect(actnImportCrashes, SIGNAL( triggered() ), actn, SLOT( slotImport() ));
 
     QAction* actnImportGaleon = actionCollection()->addAction("importGaleon");
+    actnImportGaleon->setObjectName("Galeon");
     actnImportGaleon->setText(i18n("Import &Galeon Bookmarks..."));
     connect(actnImportGaleon, SIGNAL( triggered() ), actn, SLOT( slotImport() ));
 
     QAction* actnImportKDE2 = actionCollection()->addAction("importKDE2");
-    actnImportKDE2->setText(i18n("Import &KDE2/KDE3 Bookmarks..."));
+    actnImportKDE2->setObjectName("KDE2");
+    actnImportKDE2->setIcon(KIcon("kmenu"));
+    actnImportKDE2->setText(i18n("Import &KDE 2 or KDE 3 Bookmarks..."));
+
     connect(actnImportKDE2, SIGNAL( triggered() ), actn, SLOT( slotImport() ));
 
     QAction* actnImportIE = actionCollection()->addAction("importIE");
-    actnImportIE->setText(i18n("Import &IE Bookmarks..."));
+    actnImportIE->setObjectName("IE");
+    actnImportIE->setText(i18n("Import &Internet Explorer Bookmarks..."));
     connect(actnImportIE, SIGNAL( triggered() ), actn, SLOT( slotImport() ));
 
     QAction* actnImportMoz = actionCollection()->addAction("importMoz");
+    actnImportMoz->setObjectName("Moz");
     actnImportMoz->setIcon(KIcon("mozilla"));
     actnImportMoz->setText(i18n("Import &Mozilla Bookmarks..."));
     connect(actnImportMoz, SIGNAL( triggered() ), actn, SLOT( slotImport() ));
 
     QAction* actnExportNS = actionCollection()->addAction("exportNS");
     actnExportNS->setIcon(KIcon("netscape"));
-    actnExportNS->setText(i18n("Export to &Netscape Bookmarks"));
+    actnExportNS->setText(i18n("Export &Netscape Bookmarks"));
     connect(actnExportNS, SIGNAL( triggered() ), actn, SLOT( slotExportNS() ));
 
     QAction* actnExportOpera = actionCollection()->addAction("exportOpera");
     actnExportOpera->setIcon(KIcon("opera"));
-    actnExportOpera->setText(i18n("Export to &Opera Bookmarks..."));
+    actnExportOpera->setText(i18n("Export &Opera Bookmarks..."));
     connect(actnExportOpera, SIGNAL( triggered() ), actn, SLOT( slotExportOpera() ));
 
     QAction* actnExportHTML = actionCollection()->addAction("exportHTML");
     actnExportHTML->setIcon(KIcon("html"));
-    actnExportHTML->setText(i18n("Export to &HTML Bookmarks..."));
+    actnExportHTML->setText(i18n("Export &HTML Bookmarks..."));
     connect(actnExportHTML, SIGNAL( triggered() ), actn, SLOT( slotExportHTML() ));
 
     QAction* actnExportIE = actionCollection()->addAction("exportIE");
-    actnExportIE->setText(i18n("Export to &IE Bookmarks..."));
+    actnExportIE->setText(i18n("Export &Internet Explorer Bookmarks..."));
     connect(actnExportIE, SIGNAL( triggered() ), actn, SLOT( slotExportIE() ));
 
     QAction* actnExportMoz = actionCollection()->addAction("exportMoz");
     actnExportMoz->setIcon(KIcon("mozilla"));
-    actnExportMoz->setText(i18n("Export to &Mozilla Bookmarks..."));
+    actnExportMoz->setText(i18n("Export &Mozilla Bookmarks..."));
     connect(actnExportMoz, SIGNAL( triggered() ), actn, SLOT( slotExportMoz() ));
 }
 
@@ -433,10 +442,10 @@ void ActionsImpl::slotInsertSeparator()
 
 void ActionsImpl::slotImport() {
     KEBApp::self()->bkInfo()->commitChanges();
-    // kDebug() << "ActionsImpl::slotImport() where sender()->name() == "
-    //           << sender()->name() << endl;
+    qDebug() << "ActionsImpl::slotImport() where sender()->name() == "
+               << sender()->objectName() << endl;
     ImportCommand* import
-        = ImportCommand::performImport(sender()->objectName()+6, KEBApp::self());
+        = ImportCommand::performImport(sender()->objectName(), KEBApp::self());
     if (!import)
         return;
     CmdHistory::self()->addCommand(import);
@@ -470,8 +479,8 @@ static KParts::ReadOnlyPart *s_part;
 
 void ActionsImpl::slotPrint() {
     KEBApp::self()->bkInfo()->commitChanges();
-    s_part = KParts::ComponentFactory
-                        ::createPartInstanceFromQuery<KParts::ReadOnlyPart>(
+    s_part = KServiceTypeTrader
+                        ::createInstanceFromQuery<KParts::ReadOnlyPart>(
                                 "text/html", QString());
     s_part->setProperty("pluginsEnabled", QVariant(false));
     s_part->setProperty("javaScriptEnabled", QVariant(false));
@@ -652,7 +661,7 @@ void ActionsImpl::slotSetAsToolbar() {
 void ActionsImpl::slotChangeIcon() {
     KEBApp::self()->bkInfo()->commitChanges();
     KBookmark bk = KEBApp::self()->firstSelected();
-    QString newIcon = KIconDialog::getIcon(K3Icon::Small, K3Icon::FileSystem);
+    QString newIcon = KIconDialog::getIcon(KIconLoader::Small, KIconLoader::FileSystem);
     if (newIcon.isEmpty())
         return;
     EditCommand *cmd = new EditCommand(bk.address(), -1, newIcon);
