@@ -171,7 +171,6 @@ static bool startNewKonqueror( QString url, QString mimetype, const QString& pro
 	if( profilepath.isEmpty())
 	    return true;
 	KConfig cfg(  profilepath );
-	cfg.setDollarExpansion( true );
         KConfigGroup profileGroup( &cfg, "Profile" );
 	const QMap< QString, QString > entries = profileGroup.entryMap();
 	QRegExp urlregexp( QLatin1String( "^View[0-9]*_URL$" ));
@@ -389,7 +388,7 @@ bool ClientApp::createNewWindow(const KUrl & url, bool newTab, bool tempFile, co
             if ( tempFile )
                 args << "-tempfile";
             args << url.url();
-            KProcess::startDetached(QLatin1String("kshell"), args);
+            KProcess::startDetached(QLatin1String("kshell4"), args);
 #ifdef Q_WS_X11
             KStartupInfo::resetStartupEnv();
 #endif
@@ -509,6 +508,17 @@ bool ClientApp::doIt()
       url = args->url(2).url();
     return openProfile( args->arg(1), url );
   }
+  else if ( command == "exec" && argc >= 2)
+  {
+    // compatibility with KDE 3 and xdg-open
+    QStringList kioclientArgs;
+    kioclientArgs << "exec" << args->arg(1);
+    if (argc == 3)
+        kioclientArgs << args->arg(2);
+
+    int ret = KProcess::execute("kioclient", kioclientArgs);
+    return ret == 0;
+  }
   else
   {
     fprintf( stderr, "%s", i18n("Syntax Error: Unknown command '%1'\n", command).toLocal8Bit().data() );
