@@ -265,8 +265,7 @@ Sidebar_Widget::Sidebar_Widget(QWidget *parent, KParts::ReadOnlyPart *par, bool
 	m_mainDockWidget->setDockSite(K3DockWidget::DockTop);
 	m_mainDockWidget->setEnableDocking(K3DockWidget::DockNone);
 
-   	m_buttonBar = new KMultiTabBar(KMultiTabBar::Vertical,this);
-	m_buttonBar->showActiveTabTexts(true);
+   	m_buttonBar = new KMultiTabBar(KMultiTabBar::Left,this);
 
 	// Ported to QMenu already, just needs to have KMultiTabBar fixed
 #ifdef __GNUC__
@@ -529,7 +528,7 @@ void Sidebar_Widget::slotSetURL( )
 void Sidebar_Widget::slotSetIcon( )
 {
 //	kicd.setStrictIconSize(true);
-        QString iconname=KIconDialog::getIcon(K3Icon::Small);
+        QString iconname=KIconDialog::getIcon(KIconLoader::Small);
 	kDebug()<<"New Icon Name:"<<iconname;
 	if (!iconname.isEmpty())
 	{
@@ -1136,26 +1135,15 @@ void Sidebar_Widget::popupMenu( const QPoint &global, const KFileItemList &items
 		getExtension()->popupMenu(global,items);
 }
 
-
-void Sidebar_Widget::popupMenu( KXMLGUIClient *client, const QPoint &global, const KFileItemList &items )
-{
-	if (doEnableActions())
-		getExtension()->popupMenu(client,global,items);
-}
-
-void Sidebar_Widget::popupMenu( const QPoint &global, const KUrl &url,
-	const QString &mimeType, mode_t mode)
-{
-	if (doEnableActions())
-		getExtension()->popupMenu(global,url,mimeType,mode);
-}
-
-void Sidebar_Widget::popupMenu( KXMLGUIClient *client,
+void Sidebar_Widget::popupMenu(
 	const QPoint &global, const KUrl &url,
 	const QString &mimeType, mode_t mode )
 {
-	if (doEnableActions())
-		getExtension()->popupMenu(client,global,url,mimeType,mode);
+    if (doEnableActions()) {
+        KParts::OpenUrlArguments args;
+        args.setMimeType(mimeType);
+		getExtension()->popupMenu(global,url,mode, args);
+        }
 }
 
 void Sidebar_Widget::connectModule(QObject *mod)
@@ -1174,8 +1162,8 @@ void Sidebar_Widget::connectModule(QObject *mod)
 			QPoint &, const KUrl&, const QString &, mode_t)));
 	}
 
-	if (mod->metaObject()->indexOfSignal("popupMenu(KXMLGUIClient*,QPoint,KUrl,QString,mode_t)") != -1) {
-		connect(mod,SIGNAL(popupMenu( KXMLGUIClient *, const QPoint &,
+	if (mod->metaObject()->indexOfSignal("popupMenu(QPoint,KUrl,QString,mode_t)") != -1) {
+		connect(mod,SIGNAL(popupMenu( const QPoint &,
 			const KUrl &,const QString &, mode_t)),this,
 			SLOT(popupMenu( KXMLGUIClient *, const QPoint &,
 			const KUrl &,const QString &, mode_t)));
@@ -1232,11 +1220,7 @@ void Sidebar_Widget::customEvent(QEvent* ev)
 	{
 		emit fileSelection(static_cast<KonqFileSelectionEvent*>(ev)->selection());
 	} else if (KonqFileMouseOverEvent::test(ev)) {
-		if (!(static_cast<KonqFileMouseOverEvent*>(ev)->item())) {
-			emit fileMouseOver(KFileItem(KUrl(),QString(),KFileItem::Unknown));
-		} else {
-			emit fileMouseOver(*static_cast<KonqFileMouseOverEvent*>(ev)->item());
-		}
+		emit fileMouseOver(static_cast<KonqFileMouseOverEvent*>(ev)->item());
 	}
 }
 
