@@ -36,7 +36,6 @@
 #include "konqopenurlrequest.h"
 
 #include <kparts/mainwindow.h>
-#include <kbookmarkmanager.h>
 #include <kcompletion.h>
 #include <kurlcompletion.h>
 #include <kglobalsettings.h>
@@ -54,6 +53,7 @@ class QPixmap;
 class KAction;
 class KActionCollection;
 class KActionMenu;
+class KBookmarkGroup;
 class KBookmarkMenu;
 class KBookmarkActionMenu;
 class KCMultiDialog;
@@ -67,13 +67,14 @@ class KonqFrameBase;
 class KonqFrameContainerBase;
 class KonqFrameContainer;
 class KToolBarPopupAction;
-class KonqLogoAction;
+class KAnimatedButton;
 class KonqViewManager;
 class ToggleViewGUIClient;
 class KonqMainWindowIface;
 class KonqDirPart;
 class KonqRun;
 class KUrlRequester;
+class KBookmarkManager;
 struct HistoryEntry;
 
 namespace KParts {
@@ -81,7 +82,7 @@ namespace KParts {
     class BrowserHostExtension;
     class ReadOnlyPart;
     class OpenUrlArguments;
-    class BrowserArguments;
+    struct BrowserArguments;
 }
 
 class KonqExtendedBookmarkOwner;
@@ -318,20 +319,14 @@ Q_SIGNALS:
   void popupItemsDisturbed();
 
 public Q_SLOTS:
-  void slotCtrlTabPressed();
+    void slotCtrlTabPressed();
 
-    void slotPopupMenu( const QPoint &global, const KFileItemList &items );
-    void slotPopupMenu( KXMLGUIClient *client, const QPoint &global, const KFileItemList &items, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments& browserArgs, KParts::BrowserExtension::PopupFlags flags );
-    void slotPopupMenu( const QPoint &global, const KUrl &url, const QString &mimeType, mode_t mode );
-    void slotPopupMenu( KXMLGUIClient *client, const QPoint &global, const KUrl &url, const QString &mimeType, mode_t mode );
-    void slotPopupMenu( KXMLGUIClient *client, const QPoint &global, const KUrl &url, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments& browserArgs, KParts::BrowserExtension::PopupFlags f, mode_t mode );
+    void slotPopupMenu( const QPoint &global, const KFileItemList &items, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments& browserArgs, KParts::BrowserExtension::PopupFlags flags, const KParts::BrowserExtension::ActionGroupMap& );
+    void slotPopupMenu( const QPoint &global, const KUrl &url, mode_t mode, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments& browserArgs, KParts::BrowserExtension::PopupFlags f, const KParts::BrowserExtension::ActionGroupMap& );
 
-
-    void slotPopupMenuHelper( KXMLGUIClient *client, const QPoint &global, const KFileItemList &items, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments& browserArgs, KParts::BrowserExtension::PopupFlags f, bool showProperties );
-
-  /**
-   * __NEEEEVER__ call this method directly. It relies on sender() (the part)
-   */
+    /**
+     * __NEEEEVER__ call this method directly. It relies on sender() (the part)
+     */
     void slotOpenURLRequest( const KUrl &url, const KParts::OpenUrlArguments& args, const KParts::BrowserArguments &browserArgs );
 
   void openUrlRequestHelper( KonqView *childView, const KUrl &url, const KParts::OpenUrlArguments& args, const KParts::BrowserArguments &browserArgs );
@@ -349,6 +344,7 @@ public Q_SLOTS:
   void slotNewDir();
   void slotOpenTerminal();
   void slotOpenLocation();
+  void slotOpenFile();
 
   // View menu
   void slotViewModeToggle( bool toggle );
@@ -445,8 +441,7 @@ protected Q_SLOTS:
   void slotSaveViewPropertiesLocally();
   void slotRemoveLocalProperties();
 
-  void slotOpenEmbedded();
-  void slotOpenEmbeddedDoIt();
+    void slotOpenEmbedded(KService::Ptr);
 
   // Connected to KSycoca
   void slotDatabaseChanged();
@@ -653,7 +648,7 @@ private: // members
   QAction *m_paConfigureExtensions;
   QAction *m_paConfigureSpellChecking;
 
-  KonqLogoAction *m_paAnimatedLogo;
+  KAnimatedButton *m_paAnimatedLogo;
 
   KBookmarkBar *m_paBookmarkBar;
 
@@ -663,7 +658,6 @@ private: // members
   KToggleAction *m_ptaUseHTML;
 
   KToggleAction *m_paShowMenuBar;
-  KToggleAction *m_paShowStatusBar;
 
   KToggleFullScreenAction *m_ptaFullScreen;
 
@@ -713,8 +707,6 @@ private: // members
 
   ToggleViewGUIClient *m_toggleViewGUIClient;
 
-  KService::List m_popupEmbeddingServices;
-  QString m_popupService;
   QString m_popupServiceType;
   KUrl m_popupUrl;
 
