@@ -65,7 +65,7 @@ KonqFrameTabs::KonqFrameTabs(QWidget* parent, KonqFrameContainerBase* parentCont
     m_closeOtherTabsId(0)
 {
   KAcceleratorManager::setNoAccel(this);
-  setStyleSheet("QTabWidget { border: none; }");
+  setStyleSheet("QTabWidget::pane { border: none; }");
 
   tabBar()->setWhatsThis(i18n( "This bar contains the list of currently open tabs. Click on a tab to make it "
 			  "active. The option to show a close button instead of the website icon in the left "
@@ -138,6 +138,9 @@ KonqFrameTabs::KonqFrameTabs(QWidget* parent, KonqFrameContainerBase* parentCont
            SLOT( slotReceivedDropEvent( QWidget *, QDropEvent * ) ) );
   connect( this, SIGNAL( initiateDrag( QWidget * )),
            SLOT( slotInitiateDrag( QWidget * ) ) );
+
+
+  initPopupMenu();
 }
 
 KonqFrameTabs::~KonqFrameTabs()
@@ -219,28 +222,38 @@ void KonqFrameTabs::insertChildFrame( KonqFrameBase* frame, int index )
 {
     //kDebug(1202) << "KonqFrameTabs " << this << ": insertChildFrame " << frame;
 
-    if (frame)
-    {
-      //kDebug(1202) << "Adding frame";
-      bool showTabBar = (count() == 1);
-      insertTab(index, frame->asQWidget(), "");
-      frame->setParentContainer(this);
-      if (index == -1) m_childFrameList.append(frame);
-      else m_childFrameList.insert(index, frame);
-      if (m_rightWidget)
-        m_rightWidget->setEnabled( m_childFrameList.count()>1 );
-      KonqView* activeChildView = frame->activeChildView();
-      if (activeChildView != 0L) {
-        activeChildView->setCaption( activeChildView->caption() );
-        activeChildView->setTabIcon( activeChildView->url() );
-      }
-      if (showTabBar)
-          setTabBarHidden(false);
-      else if ( count() == 1 )
-          this->hideTabBar();//the first frame inserted (initialization)
-    }
-    else
+    if (!frame) {
         kWarning(1202) << "KonqFrameTabs " << this << ": insertChildFrame(0) !" ;
+        return;
+    }
+
+    //kDebug(1202) << "Adding frame";
+
+    //QTabWidget docs say that inserting tabs while already shown causes
+    //flicker...
+    setUpdatesEnabled(false);
+
+    insertTab(index, frame->asQWidget(), "");
+
+    frame->setParentContainer(this);
+    if (index == -1) {
+        m_childFrameList.append(frame);
+    } else {
+        m_childFrameList.insert(index, frame);
+    }
+
+    if (m_rightWidget) {
+      m_rightWidget->setEnabled( m_childFrameList.count() > 1 );
+    }
+
+    if (KonqView* activeChildView = frame->activeChildView()) {
+      activeChildView->setCaption( activeChildView->caption() );
+      activeChildView->setTabIcon( activeChildView->url() );
+    }
+
+    setTabBarHidden(count() <= 1);
+
+    setUpdatesEnabled(true);
 }
 
 void KonqFrameTabs::childFrameRemoved( KonqFrameBase * frame )
@@ -289,7 +302,6 @@ void KonqFrameTabs::slotMovedTab( int from, int to )
 
 void KonqFrameTabs::slotContextMenu( const QPoint &p )
 {
-  initPopupMenu();
   refreshSubPopupMenuTab();
   m_pPopupMenu->setItemEnabled( RELOAD_ID, false );
   m_pPopupMenu->setItemEnabled( DUPLICATE_ID, false );
@@ -303,7 +315,6 @@ void KonqFrameTabs::slotContextMenu( const QPoint &p )
 
 void KonqFrameTabs::slotContextMenu( QWidget *w, const QPoint &p )
 {
-  initPopupMenu();
   refreshSubPopupMenuTab();
   uint tabCount = m_childFrameList.count();
   m_pPopupMenu->setItemEnabled( RELOAD_ID, true );
@@ -437,8 +448,8 @@ void KonqFrameTabs::slotInitiateDrag( QWidget *w )
     frame->activeChildView()->url().populateMimeData(md);
     d->setMimeData( md );
     QString iconName = KMimeType::iconNameForUrl(frame->activeChildView()->url());
-    d->setPixmap(KIconLoader::global()->loadIcon(iconName, K3Icon::Small, 0));
-    //d->setPixmap( KIconLoader::global()->loadMimeTypeIcon(KMimeType::pixmapForURL( frame->activeChildView()->url(), 0), K3Icon::Small ) );
+    d->setPixmap(KIconLoader::global()->loadIcon(iconName, KIconLoader::Small, 0));
+    //d->setPixmap( KIconLoader::global()->loadMimeTypeIcon(KMimeType::pixmapForURL( frame->activeChildView()->url(), 0), KIconLoader::Small ) );
     d->start();
   }
 }
@@ -524,7 +535,7 @@ bool KonqFrameTabs::accept( KonqFrameVisitor* visitor )
 
 void KonqFrameTabs::slotCurrentChanged( QWidget* newPage )
 {
-    const KColorScheme colorScheme(KColorScheme::Window);
+    const KColorScheme colorScheme(QPalette::Active, KColorScheme::Window);
     setTabTextColor(indexOf(newPage), colorScheme.foreground(KColorScheme::NormalText));
 
     KonqFrameBase* currentFrame = dynamic_cast<KonqFrameBase*>(newPage);
@@ -570,7 +581,7 @@ void KonqFrameTabs::setLoading(KonqFrameBase* frame, bool loading)
     if (pos == -1)
         return;
 
-    const KColorScheme colorScheme(KColorScheme::Window);
+    const KColorScheme colorScheme(QPalette::Active, KColorScheme::Window);
     QColor color;
     if (loading) {
         color = colorScheme.foreground(KColorScheme::NeutralText); // a tab is currently loading
