@@ -191,9 +191,9 @@ void KonqView::openUrl( const KUrl &url, const QString & locationBarURL,
   } else
     m_bLockHistory = false;
 
-  callExtensionStringMethod( "setNameFilter(const QString&)", nameFilter );
+  callExtensionStringMethod( "setNameFilter", nameFilter );
   if ( m_bDisableScrolling )
-    callExtensionMethod( "disableScrolling()" );
+    callExtensionMethod( "disableScrolling" );
 
   setLocationBarURL( locationBarURL );
   setPageSecurity(KonqMainWindow::NotCrypted);
@@ -270,7 +270,7 @@ void KonqView::switchView( KonqViewFactory &viewFactory )
 
   if ( !m_pMainWindow->viewManager()->isLoadingProfile() )
   {
-    // Honour "non-removeable passive mode" (like the dirtree)
+    // Honor "non-removeable passive mode" (like the dirtree)
     prop = m_service->property( "X-KDE-BrowserView-PassiveMode");
     if ( prop.isValid() && prop.toBool() )
     {
@@ -278,7 +278,7 @@ void KonqView::switchView( KonqViewFactory &viewFactory )
       setPassiveMode( true ); // set as passive
     }
 
-    // Honour "linked view"
+    // Honor "linked view"
     prop = m_service->property( "X-KDE-BrowserView-LinkedView");
     if ( prop.isValid() && prop.toBool() )
     {
@@ -345,7 +345,7 @@ bool KonqView::changeViewMode( const QString &serviceType,
 
   // Check if that's already the kind of part we have -> no need to recreate it
   // Note: we should have an operator= for KService...
-  if ( m_service && m_service->desktopEntryPath() == service->desktopEntryPath() )
+  if ( m_service && m_service->entryPath() == service->entryPath() )
   {
     kDebug( 1202 ) << "KonqView::changeViewMode. Reusing service. Service type set to " << m_serviceType;
     if (  m_pMainWindow->currentView() == this )
@@ -418,11 +418,11 @@ void KonqView::connectPart(  )
       connect( ext, SIGNAL( speedProgress( int ) ),
                m_pKonqFrame->statusbar(), SLOT( slotSpeedProgress( int ) ) );
 
-      connect( ext, SIGNAL( selectionInfo( const KFileItemList & ) ),
-               this, SLOT( slotSelectionInfo( const KFileItemList & ) ) );
+      connect( ext, SIGNAL( selectionInfo( const KFileItemList& ) ),
+               this, SLOT( slotSelectionInfo( const KFileItemList& ) ) );
 
-      connect( ext, SIGNAL( mouseOverInfo( const KFileItem * ) ),
-               this, SLOT( slotMouseOverInfo( const KFileItem * ) ) );
+      connect( ext, SIGNAL( mouseOverInfo( const KFileItem& ) ),
+               this, SLOT( slotMouseOverInfo( const KFileItem& ) ) );
 
       connect( ext, SIGNAL( openUrlNotify() ),
                this, SLOT( slotOpenURLNotify() ) );
@@ -452,7 +452,7 @@ void KonqView::connectPart(  )
                    SLOT( slotAddWebSideBar(const KUrl&, const QString&) ) );
       }
 
-      callExtensionBoolMethod( "setSaveViewPropertiesLocally(bool)", m_pMainWindow->saveViewPropertiesLocally() );
+      callExtensionBoolMethod( "setSaveViewPropertiesLocally", m_pMainWindow->saveViewPropertiesLocally() );
   }
 
   QVariant urlDropHandling;
@@ -622,7 +622,7 @@ void KonqView::slotSelectionInfo( const KFileItemList &items )
   QApplication::sendEvent( m_pMainWindow, &ev );
 }
 
-void KonqView::slotMouseOverInfo( const KFileItem *item )
+void KonqView::slotMouseOverInfo( const KFileItem& item )
 {
   KonqFileMouseOverEvent ev( item, m_pPart );
   QApplication::sendEvent( m_pMainWindow, &ev );
@@ -1054,12 +1054,7 @@ bool KonqView::callExtensionMethod( const char *methodName )
   if ( !obj ) // not all views have a browser extension !
     return false;
 
-  int id = obj->metaObject()->indexOfSlot( methodName );
-  if ( id == -1 )
-    return false;
-  QMetaObject::invokeMethod( obj, methodName,  Qt::DirectConnection);
-
-  return true;
+  return QMetaObject::invokeMethod( obj, methodName,  Qt::DirectConnection);
 }
 
 bool KonqView::callExtensionBoolMethod( const char *methodName, bool value )
@@ -1068,13 +1063,7 @@ bool KonqView::callExtensionBoolMethod( const char *methodName, bool value )
   if ( !obj ) // not all views have a browser extension !
     return false;
 
-  int id = obj->metaObject()->indexOfSlot( methodName );
-  if ( id == -1 )
-    return false;
-
-  QMetaObject::invokeMethod( obj, methodName,  Qt::DirectConnection, Q_ARG(bool,value));
-
-  return true;
+  return QMetaObject::invokeMethod( obj, methodName,  Qt::DirectConnection, Q_ARG(bool,value));
 }
 
 bool KonqView::callExtensionStringMethod( const char *methodName, const QString &value )
@@ -1083,13 +1072,7 @@ bool KonqView::callExtensionStringMethod( const char *methodName, const QString
   if ( !obj ) // not all views have a browser extension !
     return false;
 
-  int id = obj->metaObject()->indexOfSlot( methodName );
-  if ( id == -1 )
-    return false;
-
-  QMetaObject::invokeMethod( obj, methodName,  Qt::DirectConnection, Q_ARG(QString, value));
-
-  return true;
+  return QMetaObject::invokeMethod( obj, methodName,  Qt::DirectConnection, Q_ARG(QString, value));
 }
 
 bool KonqView::callExtensionURLMethod( const char *methodName, const KUrl& value )
@@ -1098,13 +1081,7 @@ bool KonqView::callExtensionURLMethod( const char *methodName, const KUrl& value
   if ( !obj ) // not all views have a browser extension !
     return false;
 
-  int id = obj->metaObject()->indexOfSlot( methodName );
-  if ( id == -1 )
-    return false;
-
-  QMetaObject::invokeMethod( obj, methodName,  Qt::DirectConnection, Q_ARG(KUrl, value));
-
-  return true;
+  return QMetaObject::invokeMethod( obj, methodName,  Qt::DirectConnection, Q_ARG(KUrl, value));
 }
 
 void KonqView::setViewName( const QString &name )
@@ -1135,33 +1112,21 @@ void KonqView::enablePopupMenu( bool b )
   if ( b ) {
     m_bPopupMenuEnabled = true;
 
-    connect( ext, SIGNAL( popupMenu( const QPoint &, const KFileItemList & ) ),
-             m_pMainWindow, SLOT( slotPopupMenu( const QPoint &, const KFileItemList & ) ) );
+    connect( ext, SIGNAL(popupMenu(QPoint,KFileItemList,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::BrowserExtension::PopupFlags,KParts::BrowserExtension::ActionGroupMap)),
+             m_pMainWindow, SLOT(slotPopupMenu(QPoint,KFileItemList,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::BrowserExtension::PopupFlags,KParts::BrowserExtension::ActionGroupMap)) );
 
-    connect( ext, SIGNAL( popupMenu( const QPoint &, const KUrl &, const QString &, mode_t ) ),
-             m_pMainWindow, SLOT( slotPopupMenu( const QPoint &, const KUrl &, const QString &, mode_t ) ) );
-
-    connect( ext, SIGNAL( popupMenu(KXMLGUIClient *, const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &, KParts::BrowserExtension::PopupFlags) ),
-             m_pMainWindow, SLOT( slotPopupMenu( KXMLGUIClient *, const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &, KParts::BrowserExtension::PopupFlags ) ) );
-
-    connect( ext, SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KUrl &, const QString &, mode_t ) ),
-             m_pMainWindow, SLOT( slotPopupMenu( KXMLGUIClient *, const QPoint &, const KUrl &, const QString &, mode_t ) ) );
-
-    connect( ext, SIGNAL( popupMenu(KXMLGUIClient *, const QPoint &, const KUrl &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &, KParts::BrowserExtension::PopupFlags, mode_t) ),
-             m_pMainWindow, SLOT( slotPopupMenu( KXMLGUIClient *, const QPoint &, const KUrl &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &, KParts::BrowserExtension::PopupFlags, mode_t ) ) );
+    connect( ext, SIGNAL(popupMenu(QPoint,KUrl,mode_t,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::BrowserExtension::PopupFlags,KParts::BrowserExtension::ActionGroupMap)),
+             m_pMainWindow, SLOT(slotPopupMenu(QPoint,KUrl,mode_t,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::BrowserExtension::PopupFlags,KParts::BrowserExtension::ActionGroupMap)) );
   }
   else // disable context popup
   {
     m_bPopupMenuEnabled = false;
 
-    disconnect( ext, SIGNAL( popupMenu( const QPoint &, const KFileItemList & ) ),
-             m_pMainWindow, SLOT( slotPopupMenu( const QPoint &, const KFileItemList & ) ) );
+    disconnect( ext, SIGNAL(popupMenu(QPoint,KFileItemList,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::BrowserExtension::PopupFlags,KParts::BrowserExtension::ActionGroupMap)),
+             m_pMainWindow, SLOT(slotPopupMenu(QPoint,KFileItemList,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::BrowserExtension::PopupFlags,KParts::BrowserExtension::ActionGroupMap)) );
 
-    disconnect( ext, SIGNAL( popupMenu( const QPoint &, const KUrl &, const QString &, mode_t ) ),
-             m_pMainWindow, SLOT( slotPopupMenu( const QPoint &, const KUrl &, const QString &, mode_t ) ) );
-
-    disconnect( ext, SIGNAL( popupMenu( KXMLGUIClient *, const QPoint &, const KUrl &, const QString &, mode_t ) ),
-             m_pMainWindow, SLOT( slotPopupMenu( KXMLGUIClient *, const QPoint &, const KUrl &, const QString &, mode_t ) ) );
+    disconnect( ext, SIGNAL(popupMenu(QPoint,KUrl,mode_t,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::BrowserExtension::PopupFlags,KParts::BrowserExtension::ActionGroupMap)),
+             m_pMainWindow, SLOT(slotPopupMenu(QPoint,KUrl,mode_t,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::BrowserExtension::PopupFlags,KParts::BrowserExtension::ActionGroupMap)) );
   }
   enableBackRightClick( m_bBackRightClick );
 }
@@ -1180,7 +1145,7 @@ void KonqView::enableBackRightClick( bool b )
 
 void KonqView::reparseConfiguration()
 {
-    callExtensionMethod( "reparseConfiguration()" );
+    callExtensionMethod( "reparseConfiguration" );
     const bool b = KonqSettings::backRightClick();
     if ( m_bBackRightClick != b ) {
         QAbstractScrollArea* scrollArea = ::qobject_cast<QAbstractScrollArea *>( m_pPart->widget() );
@@ -1198,7 +1163,7 @@ void KonqView::reparseConfiguration()
 void KonqView::disableScrolling()
 {
     m_bDisableScrolling = true;
-    callExtensionMethod( "disableScrolling()" );
+    callExtensionMethod( "disableScrolling" );
 }
 
 QString KonqView::dbusObjectPath()
