@@ -31,6 +31,8 @@
 #include <KColorScheme>
 #include <KConfig>
 #include <KLocale>
+#include <KDebug>
+#include <KConfigGroup>
 #include <KStandardDirs>
 
 using namespace Konsole;
@@ -382,7 +384,7 @@ AccessibleColorScheme::AccessibleColorScheme()
     // setup colors
     const int ColorRoleCount = 8;
 
-    const KColorScheme colorScheme;
+    const KColorScheme colorScheme(QPalette::Active);
 
     QBrush colors[ColorRoleCount] =
     {
