@@ -21,6 +21,7 @@
 #include "SessionController.h"
 
 // Qt
+#include <QtGui/QApplication>
 #include <QMenu>
 
 // KDE
@@ -29,6 +30,7 @@
 #include <KInputDialog>
 #include <KLocale>
 #include <KMenu>
+#include <KRun>
 #include <kshell.h>
 #include <KToggleAction>
 #include <KUrl>
@@ -261,6 +263,11 @@ KUrl SessionController::url() const
     return KUrl( path ); 
 }
 
+void SessionController::rename()
+{
+	renameSession();
+}
+
 void SessionController::openUrl( const KUrl& url ) 
 {
     // handle local paths
@@ -317,8 +324,6 @@ bool SessionController::eventFilter(QObject* watched , QEvent* event)
         {
             if ( _view->screenWindow() && !_viewUrlFilter )
             {
-                qDebug() << "Creating url filter";
-
                 connect( _view->screenWindow() , SIGNAL(scrolled(int)) , this ,
                         SLOT(requireUrlFilterUpdate()) );
                 connect( _view->screenWindow() , SIGNAL(outputChanged()) , this , 
@@ -397,6 +402,12 @@ void SessionController::setupActions()
     action->setText( i18n("&Close Tab") );
     action->setShortcut( QKeySequence(Qt::CTRL+Qt::SHIFT+Qt::Key_W) );
     connect( action , SIGNAL(triggered()) , this , SLOT(closeSession()) );
+
+    // Open Browser
+    action = collection->addAction("open-browser");
+    action->setText( i18n("Open Browser Here") );
+    action->setIcon( KIcon("folder-open") );
+    connect( action, SIGNAL(triggered()), this, SLOT(openBrowser()) );
     
     // Copy and Paste
     action = collection->addAction("copy");
@@ -620,6 +631,12 @@ void SessionController::closeSession()
     _session->close();
 }
 
+void SessionController::openBrowser()
+{
+    kDebug() << "url is" << url();
+    new KRun(url(), QApplication::activeWindow());
+}
+
 void SessionController::copy()
 {
     _view->copyClipboard(); 
@@ -641,6 +658,7 @@ void SessionController::clearAndReset()
     Emulation* emulation = _session->emulation();
 
     emulation->reset();
+    _session->refresh();
 }
 void SessionController::searchClosed()
 {
@@ -1002,11 +1020,11 @@ void SaveHistoryTask::execute()
 
         KIO::TransferJob* job = KIO::put( url, 
                                           -1,   // no special permissions
-                                          true, // overwrite existing files
-                                          false,// do not resume an existing transfer
-                                          !url.isLocalFile() // show progress information only for remote
-                                                             // URLs
-                                                             //
+                                          // overwrite existing files
+                                          // do not resume an existing transfer
+                                          // show progress information only for remote
+                                          // URLs
+                                          KIO::Overwrite | (url.isLocalFile() ? KIO::HideProgressInfo : KIO::DefaultFlags)
                                                              // a better solution would be to show progress
                                                              // information after a certain period of time
                                                              // instead, since the overall speed of transfer
