@@ -29,6 +29,7 @@
 #include <QtGui/QClipboard>
 #include <QtGui/QKeyEvent>
 #include <QtCore/QEvent>
+#include <QtCore/QTime>
 #include <QtCore/QFile>
 #include <QtGui/QGridLayout>
 #include <QtGui/QLabel>
@@ -56,6 +57,7 @@
 #include "Filter.h"
 #include "konsole_wcwidth.h"
 #include "ScreenWindow.h"
+#include "TerminalCharacterDecoder.h"
 
 using namespace Konsole;
 
@@ -266,11 +268,7 @@ TerminalDisplay::TerminalDisplay(QWidget *parent)
 ,_hasBlinkingCursor(false)
 ,_ctrlDrag(false)
 ,_cutToBeginningOfLine(false)
-,_isPrinting(false)
-,_printerFriendly(false)
-,_printerBold(false)
 ,_isFixedSize(false)
-,_drop(0)
 ,_possibleTripleClick(false)
 ,_resizeWidget(0)
 ,_resizeLabel(0)
@@ -280,16 +278,6 @@ TerminalDisplay::TerminalDisplay(QWidget *parent)
 ,_colorsInverted(false)
 ,_rimX(1)
 ,_rimY(1)
-,_imPreeditText(QString())
-,_imPreeditLength(0)
-,_imStart(0)
-,_imStartLine(0)
-,_imEnd(0)
-,_imSelStart(0)
-,_imSelEnd(0)
-,_cursorLine(0)
-,_cursorCol(0)
-,_isIMEdit(false)
 ,_blendColor(qRgba(0,0,0,0xff))
 ,_filterChain(new TerminalImageFilterChain())
 ,_cursorShape(BlockCursor)
@@ -324,7 +312,8 @@ TerminalDisplay::TerminalDisplay(QWidget *parent)
   dragInfo.state = diNone;
 
   setFocusPolicy( Qt::WheelFocus );
-  // im
+
+  // enable input method support
   setAttribute(Qt::WA_InputMethodEnabled, true);
 
   // this is an important optimization, it tells Qt
@@ -573,7 +562,14 @@ void TerminalDisplay::drawCursor(QPainter& painter,
 
        if ( _cursorShape == BlockCursor )
        {
-            painter.drawRect(cursorRect);
+            // draw the cursor outline, adjusting the area so that
+            // it is draw entirely inside 'rect'
+            int penWidth = qMax(1,painter.pen().width());
+
+            painter.drawRect(cursorRect.adjusted(penWidth/2,
+                                                 penWidth/2,
+                                                 - penWidth/2 - penWidth%2,
+                                                 - penWidth/2 - penWidth%2));
             if ( hasFocus() )
             {
                 painter.fillRect(cursorRect, _cursorColor.isValid() ? _cursorColor : foregroundColor);
@@ -670,6 +666,7 @@ void TerminalDisplay::drawTextFragment(QPainter& painter ,
 void TerminalDisplay::setRandomSeed(uint randomSeed) { _randomSeed = randomSeed; }
 uint TerminalDisplay::randomSeed() const { return _randomSeed; }
 
+#if 0
 /*!
     Set XIM Position
 */
@@ -687,6 +684,7 @@ void TerminalDisplay::setCursorPos(const int curx, const int cury)
     _cursorLine = cury;
     _cursorCol = curx;
 }
+#endif
 
 // scrolls the image by 'lines', down if lines > 0 or up otherwise.
 //
@@ -850,21 +848,14 @@ void TerminalDisplay::updateImage()
     // mark surrounding neighbours dirty, in case the character exceeds
     // its cell boundaries
     memset(dirtyMask, 0, columnsToUpdate+2);
-    // Two extra so that we don't have to have to care about start and end conditions
-    for (x = 0; x < columnsToUpdate; x++)
+   
+    for( x = 0 ; x < columnsToUpdate ; x++)
     {
-	if ( ( (_imPreeditLength > 0) && 
-           ( ( _imStartLine == y ) && 
-             ( ( _imStart < _imEnd ) && 
-               ( ( x > _imStart ) ) && 
-               ( x < _imEnd ) )
-              || ( ( _imSelStart < _imSelEnd ) && ( ( x > _imSelStart ) ) ) ) )
-            || newLine[x] != currentLine[x])
-      {
-         dirtyMask[x] = dirtyMask[x+1] = dirtyMask[x+2] = 1;
-      }
+        if ( newLine[x] != currentLine[x] ) 
+        {
+            dirtyMask[x] = true;
+        }
     }
-    dirtyMask++; // Position correctly
 
     if (!_resizing) // not while _resizing, we're expecting a paintEvent
     for (x = 0; x < columnsToUpdate; x++)
@@ -907,32 +898,6 @@ void TerminalDisplay::updateImage()
 
         QString unistr(disstrU, p);
 
-        // for XIM on the spot input style
-        _isIMEdit = _isIMSel = false;
-
-        if ( _imStartLine == y ) 
-        {
-          if (  ( _imStart < _imEnd ) && 
-                ( x >= _imStart-1 ) && 
-                ( x + int( unistr.length() ) <= _imEnd ) 
-             )
-                _isIMEdit = true;
-
-          if ( ( _imSelStart < _imSelEnd ) && 
-               ( x >= _imStart-1 ) && 
-               ( x + int( unistr.length() ) <= _imEnd ) 
-             )
-                _isIMSel = true;
-	    }
-        else if ( _imStartLine < y ) 
-        {  // for word warp
-          if ( _imStart < _imEnd )
-            _isIMEdit = true;
-
-          if (  _imSelStart < _imSelEnd )
-            _isIMSel = true;
-	    }
-
         bool save__fixedFont = _fixedFont;
         if (lineDraw)
            _fixedFont = false;
@@ -970,8 +935,6 @@ void TerminalDisplay::updateImage()
         dirtyRegion |= dirtyRect;
     }
 
-    dirtyMask--; // Set back
-
     // replace the line of characters in the old _image with the 
     // current line of the new _image 
     memcpy((void*)currentLine,(const void*)newLine,columnsToUpdate*sizeof(Character));
@@ -1004,6 +967,8 @@ void TerminalDisplay::updateImage()
   }
   _usedColumns = columnsToUpdate;
 
+  dirtyRegion |= _inputMethodData.previousPreeditRect;
+
   //qDebug() << "Expecting to update: " << dirtyRegion.boundingRect();
 
   // update the parts of the display which have changed
@@ -1082,47 +1047,44 @@ void TerminalDisplay::paintEvent( QPaintEvent* pe )
   foreach (QRect rect, (pe->region() & contentsRect()).rects())
   {
     drawBackground(paint,rect,palette().background().color());
-    paintContents(paint, rect);
+    drawContents(paint, rect);
   }
+  drawInputMethodPreeditString(paint,preeditRect());
   paintFilters(paint);
 
   paint.end();
 }
 
-void TerminalDisplay::print(QPainter &paint, bool friendly, bool exact)
+QRect TerminalDisplay::preeditRect() const
 {
-   bool saveFixedFont = _fixedFont;
-   bool saveBlinking = _blinking;
-   _fixedFont = false;
-   _blinking = false;
-   paint.setFont(font());
+    const int preeditLength = string_width(_inputMethodData.preeditString);
 
-   _isPrinting = true;
-   _printerFriendly = friendly;
-   _printerBold = !exact;
+    if ( preeditLength == 0 )
+        return QRect();
 
-   if (exact)
-   {
-     QPixmap pm(contentsRect().right(), contentsRect().bottom());
-     pm.fill();
+    return QRect(_bX + _fontWidth*_screenWindow->cursorPosition().x(),
+                 _bY + _fontHeight*_screenWindow->cursorPosition().y(),
+                 _fontWidth*preeditLength,
+                 _fontHeight);
+}   
 
-     QPainter pm_paint;
-     pm_paint.begin(&pm);
-     paintContents(pm_paint, contentsRect());
-     pm_paint.end();
-     paint.drawPixmap(0, 0, pm);
-   }
-   else
-   {
-     paintContents(paint, contentsRect());
-   }
+void TerminalDisplay::drawInputMethodPreeditString(QPainter& painter , const QRect& rect)
+{
+    if ( _inputMethodData.preeditString.isEmpty() )
+        return;
 
-   _printerFriendly = false;
-   _isPrinting = false;
-   _printerBold = false;
+    const QPoint cursorPos = _screenWindow->cursorPosition();
 
-   _fixedFont = saveFixedFont;
-   _blinking = saveBlinking;
+    bool invertColors = false;
+    const QColor background = _colorTable[DEFAULT_BACK_COLOR].color;
+    const QColor foreground = _colorTable[DEFAULT_FORE_COLOR].color;
+    const Character* style = &_image[loc(cursorPos.x(),cursorPos.y())];
+
+    drawBackground(painter,rect,background);
+    drawCursor(painter,rect,foreground,background,invertColors);
+    drawCharacters(painter,rect,_inputMethodData.preeditString,style,invertColors);
+
+    _inputMethodData.previousPreeditRect = rect; 
 }
 
 FilterChain* TerminalDisplay::filterChain() const
@@ -1137,7 +1099,7 @@ void TerminalDisplay::paintFilters(QPainter& painter)
     QPoint cursorPos = mapFromGlobal(QCursor::pos());
     int cursorLine;
     int cursorColumn;
-    characterPosition( cursorPos , cursorLine , cursorColumn );
+    getCharacterPosition( cursorPos , cursorLine , cursorColumn );
     Character cursorCharacter = _image[loc(cursorColumn,cursorLine)];
 
     painter.setPen( QPen(cursorCharacter.foregroundColor.color(colorTable())) );
@@ -1209,7 +1171,7 @@ void TerminalDisplay::paintFilters(QPainter& painter)
         }
     }
 }
-void TerminalDisplay::paintContents(QPainter &paint, const QRect &rect)
+void TerminalDisplay::drawContents(QPainter &paint, const QRect &rect)
 {
   QPoint tL  = contentsRect().topLeft();
   int    tLx = tL.x();
@@ -1320,7 +1282,7 @@ void TerminalDisplay::paintContents(QPainter &paint, const QRect &rect)
 		 //reset back to single-width, single-height _lines 
 		 paint.resetMatrix();
 
-		 if (y < _lineProperties.size())
+		 if (y < _lineProperties.size()-1)
 		 {
 			//double-height _lines are represented by two adjacent _lines 
             //containing the same characters
@@ -1347,7 +1309,7 @@ void TerminalDisplay::blinkEvent()
   update();
 }
 
-QRect TerminalDisplay::imageToWidget(const QRect& imageArea)
+QRect TerminalDisplay::imageToWidget(const QRect& imageArea) const
 {
     QRect result;
     result.setLeft( _bX + _fontWidth * imageArea.left() );
@@ -1398,6 +1360,7 @@ void TerminalDisplay::updateImageSize()
   Character* oldimg = _image;
   int oldlin = _lines;
   int oldcol = _columns;
+
   makeImage();
   
   // copy the old image to reduce flicker
@@ -1406,9 +1369,11 @@ void TerminalDisplay::updateImageSize()
 
   if (oldimg)
   {
-    for (int line = 0; line < lines; line++)
+    for (int line = 0; line < lines; line++) 
+    {
       memcpy((void*)&_image[_columns*line],
              (void*)&oldimg[oldcol*line],columns*sizeof(Character));
+    }
     delete[] oldimg;
   }
 
@@ -1487,11 +1452,15 @@ void TerminalDisplay::setScrollBarPosition(ScrollBarPosition position)
 {
   if (_scrollbarLocation == position) 
       return; 
-  
+ 
+  if ( position == NoScrollBar )
+     _scrollBar->hide();
+  else 
+     _scrollBar->show(); 
+
   _bY = _bX = 1;
   _scrollbarLocation = position;
   
-  calcGeometry();
   propagateSize();
   update();
 }
@@ -1509,7 +1478,7 @@ void TerminalDisplay::mousePressEvent(QMouseEvent* ev)
 
   int charLine;
   int charColumn;
-  characterPosition(ev->pos(),charLine,charColumn);
+  getCharacterPosition(ev->pos(),charLine,charColumn);
   QPoint pos = QPoint(charColumn,charLine);
 
   Filter::HotSpot* spot = _filterChain->hotSpotAt(charLine,charColumn);
@@ -1596,13 +1565,14 @@ void TerminalDisplay::mouseMoveEvent(QMouseEvent* ev)
   int charLine = 0;
   int charColumn = 0;
 
-  characterPosition(ev->pos(),charLine,charColumn); 
+  getCharacterPosition(ev->pos(),charLine,charColumn); 
 
   // handle filters
   // change link hot-spot appearance on mouse-over
   Filter::HotSpot* spot = _filterChain->hotSpotAt(charLine,charColumn);
   if ( spot && spot->type() == Filter::HotSpot::Link)
   {
+    QRect previousHotspotArea = _mouseOverHotspotArea;
     _mouseOverHotspotArea.setCoords( qMin(spot->startColumn() , spot->endColumn()) * _fontWidth,
                                      spot->startLine() * _fontHeight,
                                      qMax(spot->startColumn() , spot->endColumn()) * _fontHeight,
@@ -1618,7 +1588,7 @@ void TerminalDisplay::mouseMoveEvent(QMouseEvent* ev)
         QToolTip::showText( mapToGlobal(ev->pos()) , tooltip , this , _mouseOverHotspotArea );
     }
 
-    update( _mouseOverHotspotArea );
+    update( _mouseOverHotspotArea | previousHotspotArea );
   }
   else if ( _mouseOverHotspotArea.isValid() )
   {
@@ -1731,7 +1701,7 @@ void TerminalDisplay::extendSelection( const QPoint& position )
 
   int charColumn = 0;
   int charLine = 0;
-  characterPosition(pos,charLine,charColumn);
+  getCharacterPosition(pos,charLine,charColumn);
 
   QPoint here = QPoint(charColumn,charLine); //QPoint((pos.x()-tLx-_bX+(_fontWidth/2))/_fontWidth,(pos.y()-tLy-_bY)/_fontHeight);
   QPoint ohere;
@@ -1903,7 +1873,7 @@ void TerminalDisplay::mouseReleaseEvent(QMouseEvent* ev)
 
     int charLine;
     int charColumn;
-    characterPosition(ev->pos(),charLine,charColumn);
+    getCharacterPosition(ev->pos(),charLine,charColumn);
 
     // handle filters
     Filter::HotSpot* spot = _filterChain->hotSpotAt(charLine,charColumn);
@@ -1961,7 +1931,7 @@ void TerminalDisplay::mouseReleaseEvent(QMouseEvent* ev)
   }
 }
 
-void TerminalDisplay::characterPosition(const QPoint& widgetPoint,int& line,int& column)
+void TerminalDisplay::getCharacterPosition(const QPoint& widgetPoint,int& line,int& column) const
 {
     column = (widgetPoint.x()-contentsRect().left()-_bX) / _fontWidth;
     line = (widgetPoint.y()-contentsRect().top()-_bY) / _fontHeight;
@@ -1994,7 +1964,7 @@ void TerminalDisplay::mouseDoubleClickEvent(QMouseEvent* ev)
   int charLine = 0;
   int charColumn = 0;
 
-  characterPosition(ev->pos(),charLine,charColumn);
+  getCharacterPosition(ev->pos(),charLine,charColumn);
 
   QPoint pos(charColumn,charLine);
 
@@ -2087,7 +2057,7 @@ void TerminalDisplay::wheelEvent( QWheelEvent* ev )
   {
     int charLine;
     int charColumn;
-    characterPosition( ev->pos() , charLine , charColumn );
+    getCharacterPosition( ev->pos() , charLine , charColumn );
     
     emit mouseSignal( ev->delta() > 0 ? 4 : 5, 
                       charColumn + 1, 
@@ -2107,7 +2077,7 @@ void TerminalDisplay::mouseTripleClickEvent(QMouseEvent* ev)
 
   int charLine;
   int charColumn;
-  characterPosition(ev->pos(),charLine,charColumn);
+  getCharacterPosition(ev->pos(),charLine,charColumn);
   _iPntSel = QPoint(charColumn,charLine);
 
   _screenWindow->clearSelection();
@@ -2322,76 +2292,51 @@ void TerminalDisplay::keyPressEvent( QKeyEvent* event )
     event->accept();
 }
 
-void TerminalDisplay::inputMethodEvent ( QInputMethodEvent *  )
+void TerminalDisplay::inputMethodEvent( QInputMethodEvent* event )
 {
-#ifdef __GNUC__
-   #warning "TODO: Implement Input Method Event feature"
-#endif
-}
+    QKeyEvent keyEvent(QEvent::KeyPress,0,Qt::NoModifier,event->commitString());
+    emit keyPressedSignal(&keyEvent);
 
-#if 0
-void TerminalDisplay::imStartEvent( QIMEvent */*e*/ )
+    _inputMethodData.preeditString = event->preeditString();
+    update(preeditRect() | _inputMethodData.previousPreeditRect);
+    
+    event->accept();
+}
+QVariant TerminalDisplay::inputMethodQuery( Qt::InputMethodQuery query ) const
 {
-  _imStart = _cursorCol;
-  _imStartLine = _cursorLine;
-  _imPreeditLength = 0;
+    const QPoint cursorPos = _screenWindow->cursorPosition();
+    switch ( query ) 
+    {
+        case Qt::ImMicroFocus:
+                return imageToWidget(QRect(cursorPos.x(),cursorPos.y(),1,1));
+            break;
+        case Qt::ImFont:
+                return font();
+            break;
+        case Qt::ImCursorPosition:
+                // return the cursor position within the current line
+                return cursorPos.x();
+            break;
+        case Qt::ImSurroundingText:
+            {
+                // return the text from the current line
+                QString lineText;
+                QTextStream stream(&lineText);
+                PlainTextDecoder decoder;
+                decoder.begin(&stream);
+                decoder.decodeLine(&_image[loc(0,cursorPos.y())],_usedColumns,_lineProperties[cursorPos.y()]);
+                decoder.end();
+                return lineText;
+            }
+            break;
+        case Qt::ImCurrentSelection:
+                return QString();
+            break;
+    }
 
-  _imEnd = _imSelStart = _imSelEnd = 0;
-  _isIMEdit = _isIMSel = false;
+    return QVariant();
 }
 
-void TerminalDisplay::imComposeEvent( QIMEvent *e )
-{
-  QString text.characterlear();
-  if ( _imPreeditLength > 0 ) {
-    text.fill( '\010', _imPreeditLength );
-  }
-
-  _imEnd = _imStart + string_width( e->text() );
-
-  QString tmpStr = e->text().left( e->cursorPos() );
-  _imSelStart = _imStart + string_width( tmpStr );
-
-  tmpStr = e->text().mid( e->cursorPos(), e->selectionLength() );
-  _imSelEnd = _imSelStart + string_width( tmpStr );
-  _imPreeditLength = e->text().length();
-  _imPreeditText = e->text();
-  text += e->text();
-
-  if ( text.length() > 0 ) {
-    QKeyEvent ke( QEvent::KeyPress, 0, -1, 0, text );
-    emit keyPressedSignal( &ke );
-  }
-}
-
-void TerminalDisplay::imEndEvent( QIMEvent *e )
-{
-  QString text.characterlear();
-  if ( _imPreeditLength > 0 ) {
-      text.fill( '\010', _imPreeditLength );
-  }
-
-  _imEnd = _imSelStart = _imSelEnd = 0;
-  text += e->text();
-  if ( text.length() > 0 ) {
-    QKeyEvent ke( QEvent::KeyPress, 0, -1, 0, text );
-    emit keyPressedSignal( &ke );
-  }
-
-  QPoint tL  = contentsRect().topLeft();
-  int tLx = tL.x();
-  int tLy = tL.y();
-
-  QRect repaintRect = QRect( _bX+tLx, _bY+tLy+_fontHeight*_imStartLine,
-                             contentsRect().width(), contentsRect().height() );
-  _imStart = 0;
-  _imPreeditLength = 0;
-
-  _isIMEdit = _isIMSel = false;
-  repaint( repaintRect, true );
-}
-#endif
-
 // Override any Ctrl+<key> accelerator when pressed with the keyboard
 // focus in TerminalDisplay, so that the key will be passed to the terminal instead.
 bool TerminalDisplay::event( QEvent *e )
@@ -2456,8 +2401,6 @@ void TerminalDisplay::bell(const QString& message)
     _allowBell = false;
     QTimer::singleShot(500,this,SLOT(enableBell()));
  
-    kDebug(1211) << __FUNCTION__;
-
     if (_bellMode==BELL_SYSTEM) 
     {
         KNotification::beep();
@@ -2506,19 +2449,16 @@ void TerminalDisplay::calcGeometry()
     case NoScrollBar :
      _bX = _rimX;
      _contentWidth = contentsRect().width() - 2 * _rimX;
-     _scrollBar->hide();
      break;
     case ScrollBarLeft :
      _bX = _rimX+_scrollBar->width();
      _contentWidth = contentsRect().width() - 2 * _rimX - _scrollBar->width();
      _scrollBar->move(contentsRect().topLeft());
-     _scrollBar->show();
      break;
     case ScrollBarRight:
      _bX = _rimX;
      _contentWidth = contentsRect().width()  - 2 * _rimX - _scrollBar->width();
      _scrollBar->move(contentsRect().topRight() - QPoint(_scrollBar->width()-1,0));
-     _scrollBar->show();
      break;
   }
 
@@ -2551,7 +2491,8 @@ void TerminalDisplay::makeImage()
   
   // We over-commit one character so that we can be more relaxed in dealing with
   // certain boundary conditions: _image[_imageSize] is a valid but unused position
-  _image = new Character[_imageSize+1]; 
+  _image = new Character[_imageSize+1];
+
   clearImage();
 }
 
@@ -2613,71 +2554,41 @@ void TerminalDisplay::dragEnterEvent(QDragEnterEvent* event)
       event->acceptProposedAction();
 }
 
-enum dropPopupOptions { paste, cd, cp, ln, mv };
-
 void TerminalDisplay::dropEvent(QDropEvent* event)
 {
-   if (_drop==0)
-   {
-      _drop = new KMenu( this );
-      _pasteAction = _drop->addAction( i18n( "Paste" ) );
-      _drop->addSeparator();
-      _cdAction = _drop->addAction( i18n( "Change Directory" ) );
-      _mvAction = _drop->addAction( i18n( "Move Here" ) );
-      _cpAction = _drop->addAction( i18n( "Copy Here" ) );
-      _lnAction = _drop->addAction( i18n( "Link Here" ) );
-      _pasteAction->setData( QVariant( paste ) );
-      _cdAction->setData( QVariant( cd ) );
-      _mvAction->setData( QVariant( mv ) );
-      _cpAction->setData( QVariant( cp ) );
-      _lnAction->setData( QVariant( ln ) );
-      connect(_drop, SIGNAL(triggered(QAction*)), SLOT(drop_menu_activated(QAction*)));
-   };
-    // The current behaviour when url(s) are dropped is
-    // * if there is only ONE url and if it's a LOCAL one, ask for paste or cd/cp/ln/mv
-    // * if there are only LOCAL urls, ask for paste or cp/ln/mv
-    // * in all other cases, just paste
-    //   (for non-local ones, or for a list of URLs, 'cd' is nonsense)
-  _dndFileCount = 0;
-  _dropText = "";
-  bool justPaste = true;
+  KUrl::List urls = KUrl::List::fromMimeData(event->mimeData());
 
-  KUrl::List urllist = KUrl::List::fromMimeData(event->mimeData());
-  if (urllist.count()) {
-    justPaste =false;
-    KUrl::List::Iterator it;
+  QString dropText;
+  if (!urls.isEmpty()) 
+  {
+    for ( int i = 0 ; i < urls.count() ; i++ ) 
+    {
+        KUrl url = KIO::NetAccess::mostLocalUrl( urls[i] , 0 );
+        QString urlText;
 
-    _cdAction->setEnabled( true );
-    _lnAction->setEnabled( true );
+        if (url.isLocalFile())
+            urlText = url.path(); 
+        else
+            urlText = url.url();
+    
+        // in future it may be useful to be able to insert file names with drag-and-drop
+        // without quoting them (this only affects paths with spaces in) 
+        urlText = KShell::quoteArg(urlText);
+      
+        dropText += urlText;
 
-    for ( it = urllist.begin(); it != urllist.end(); ++it ) {
-      if(_dndFileCount++ > 0) {
-        _dropText += ' ';
-        _cdAction->setEnabled( false );
-      }
-      KUrl url = KIO::NetAccess::mostLocalUrl( *it, 0 );
-      QString tmp;
-      if (url.isLocalFile()) {
-        tmp = url.path(); // local URL : remove protocol. This helps "ln" & "cd" and doesn't harm the others
-      } else if ( url.protocol() == QLatin1String( "mailto" ) ) {
-        justPaste = true;
-        break;
-      } else {
-        tmp = url.url();
-        _cdAction->setEnabled( false );
-        _lnAction->setEnabled( false );
-      }
-      if (urllist.count()>1)
-        tmp = KShell::quoteArg(tmp);
-      _dropText += tmp;
+        if ( i != urls.count()-1 ) 
+            dropText += ' ';
     }
-
-    if (!justPaste) _drop->popup(mapToGlobal(event->pos()));
   }
-  if(justPaste && event->mimeData()->hasFormat("text/plain")) {
-    kDebug(1211) << "Drop:" << _dropText.toLocal8Bit() << "\n";
-    emit sendStringToEmu(_dropText.toLocal8Bit());
-    // Paste it
+  else 
+  {
+    dropText = event->mimeData()->text();
+  }
+
+  if(event->mimeData()->hasFormat("text/plain")) 
+  {
+    emit sendStringToEmu(dropText.toLocal8Bit());
   }
 }
 
@@ -2692,53 +2603,6 @@ void TerminalDisplay::doDrag()
   // Don't delete the QTextDrag object.  Qt will delete it when it's done with it.
 }
 
-void TerminalDisplay::drop_menu_activated(QAction* action)
-{
-  int item = action->data().toInt();
-  switch (item)
-  {
-   case paste:
-      if (_dndFileCount==1)
-        _dropText = KShell::quoteArg(_dropText);
-      emit sendStringToEmu(_dropText.toLocal8Bit());
-      activateWindow();
-      break;
-   case cd:
-     emit sendStringToEmu("cd ");
-      struct stat statbuf;
-      if ( ::stat( QFile::encodeName( _dropText ), &statbuf ) == 0 )
-      {
-         if ( !S_ISDIR(statbuf.st_mode) )
-         {
-            KUrl url;
-            url.setPath( _dropText );
-            _dropText = url.directory( KUrl::ObeyTrailingSlash ); // remove filename
-         }
-      }
-      _dropText = KShell::quoteArg(_dropText);
-      emit sendStringToEmu(_dropText.toLocal8Bit());
-      emit sendStringToEmu("\n");
-      activateWindow();
-      break;
-   case cp:
-     emit sendStringToEmu("kfmclient copy " );
-     break;
-   case ln:
-     emit sendStringToEmu("ln -s ");
-     break;
-   case mv:
-     emit sendStringToEmu("kfmclient move " );
-     break;
-   }
-   if (item>cd && item<=mv) {
-      if (_dndFileCount==1)
-        _dropText = KShell::quoteArg(_dropText);
-      emit sendStringToEmu(_dropText.toLocal8Bit());
-      emit sendStringToEmu(" .\n");
-      activateWindow();
-   }
-}
-
 void TerminalDisplay::outputSuspended(bool suspended)
 {
 	//create the label when this function is first called
