@@ -75,9 +75,15 @@ public:
     const ColorEntry* colorTable() const;
     /** Sets the terminal color palette used by the display. */
     void setColorTable(const ColorEntry table[]);
-    /** TODO: Document me */
+    /**
+     * Sets the seed used to generate random colors for the display
+     * (in color schemes that support them).
+     */
     void setRandomSeed(uint seed);
-    /** TODO: Document me */
+    /**
+     * Returns the seed used to generate random colors for the display
+     * (in color schemes that support them).
+     */
     uint randomSeed() const;
 
     /** Sets the opacity of the terminal display. */
@@ -154,7 +160,7 @@ public:
 
     void emitSelection(bool useXselection,bool appendReturn);
 
-    void setCursorPos(const int curx, const int cury);
+//    void setCursorPos(const int curx, const int cury);
 
     /**
      * This enum describes the available shapes for the keyboard cursor.
@@ -351,8 +357,6 @@ public:
     void setBidiEnabled(bool set) { _bidiEnabled=set; }
     bool isBidiEnabled() { return _bidiEnabled; }
 
-    void print(QPainter &paint, bool friendly, bool exact);
-
     /** 
      * Sets the margin between the top-left edge of the terminal display 
      * and the rendered text.
@@ -508,7 +512,9 @@ protected:
 
     void mouseTripleClickEvent(QMouseEvent* ev);
 
-    virtual void inputMethodEvent ( QInputMethodEvent * e );
+    // reimplemented
+    virtual void inputMethodEvent ( QInputMethodEvent* event );
+    virtual QVariant inputMethodQuery( Qt::InputMethodQuery query ) const;
 
 protected slots:
 
@@ -522,7 +528,6 @@ protected slots:
 
 private slots:
 
-    void drop_menu_activated(QAction*);
     void swapColorTable();
     void tripleClickTimeout();  // resets possibleTripleClick
 
@@ -533,7 +538,7 @@ private:
     // divides the part of the display specified by 'rect' into
     // fragments according to their colors and styles and calls
     // drawTextFragment() to draw the fragments 
-    void paintContents(QPainter &paint, const QRect &rect);
+    void drawContents(QPainter &paint, const QRect &rect);
     // draws a section of text, all the text in this section
     // has a common color and style
     void drawTextFragment(QPainter& painter, const QRect& rect, 
@@ -550,14 +555,20 @@ private:
 	void drawLineCharString(QPainter& painter, int x, int y, 
                             const QString& str, const Character* attributes);
 
+    // draws the preedit string for input methods
+    void drawInputMethodPreeditString(QPainter& painter , const QRect& rect);
+
     // --
 
     // maps an area in the character image to an area on the widget 
-    QRect imageToWidget(const QRect& imageArea);
+    QRect imageToWidget(const QRect& imageArea) const;
 
     // maps a point on the widget to the position ( ie. line and column ) 
     // of the character at that point.
-    void characterPosition(const QPoint& widgetPoint,int& line,int& column);
+    void getCharacterPosition(const QPoint& widgetPoint,int& line,int& column) const;
+
+    // the area where the preedit string for input methods will be draw
+    QRect preeditRect() const;
 
     // shows a notification window in the middle of the widget indicating the terminal's
     // current size in columns and lines
@@ -646,9 +657,6 @@ private:
     bool _hasBlinkingCursor;  // has blinking cursor enabled
     bool _ctrlDrag;           // require Ctrl key for drag
     bool _cutToBeginningOfLine; // triple click only selects forward
-    bool _isPrinting; // Paint job is intended for printer
-    bool _printerFriendly; // paint printer friendly, save ink
-    bool _printerBold; // Use a bold font instead of overstrike for bold
     bool _isFixedSize; //Columns / lines are locked.
     QTimer* _blinkTimer;  // active when hasBlinker
     QTimer* _blinkCursorTimer;  // active when hasBlinkingCursor
@@ -678,31 +686,26 @@ private:
     int _rimY;      // top/bottom rim high
     QSize _size;
 	
-    QString _imPreeditText;
-    int _imPreeditLength;
-    int _imStart;
-    int _imStartLine;
-    int _imEnd;
-    int _imSelStart;
-    int _imSelEnd;
-    int _cursorLine;
-    int _cursorCol;
-    bool _isIMEdit;
-    bool _isIMSel;
-
     QRgb _blendColor;
 
-    QAction* _pasteAction;
-    QAction* _cdAction;
-    QAction* _cpAction;
-    QAction* _mvAction;
-    QAction* _lnAction;
-
+    // list of filters currently applied to the display.  used for links and
+    // search highlight
     TerminalImageFilterChain* _filterChain;
     QRect _mouseOverHotspotArea;
 
     KeyboardCursorShape _cursorShape;
-    QColor _cursorColor;
+
+    // custom cursor color.  if this is invalid then the foreground
+    // color of the character under the cursor is used
+    QColor _cursorColor;  
+
+
+    struct InputMethodData
+    {
+        QString preeditString;
+        QRect previousPreeditRect;
+    };
+    InputMethodData _inputMethodData;
 
 	//the delay in milliseconds between redrawing blinking text
 	static const int BLINK_DELAY = 500;
