@@ -39,6 +39,8 @@
 #include <kcolorscheme.h>
 #include <kcolorutils.h>
 #include <KIconLoader>
+#include <kdebug.h>
+#include <kconfiggroup.h>
 #include <KLocale>
 #include <KMenu>
 #include <KColorCollection>
@@ -60,6 +62,11 @@ ViewContainer::ViewContainer(NavigationPosition position , QObject* parent)
 }
 ViewContainer::~ViewContainer()
 {
+    foreach( QWidget* view , _views ) 
+    {
+        disconnect(view,SIGNAL(destroyed(QObject*)),this,SLOT(viewDestroyed(QObject*)));
+    }
+
     emit destroyed(this);
 }
 void ViewContainer::moveViewWidget( int , int ) {}
@@ -142,6 +149,13 @@ void ViewContainer::viewDestroyed(QObject* object)
     _views.removeAll(widget);
     _navigation.remove(widget);
 
+    // FIXME This can result in ViewContainerSubClass::removeViewWidget() being 
+    // called after the the widget's parent has been deleted or partially deleted
+    // in the ViewContainerSubClass instance's destructor.
+    //
+    // Currently deleteLater() is used to remove child widgets in the subclass 
+    // constructors to get around the problem, but this is a hack and needs
+    // to be fixed. 
     removeViewWidget(widget);
     
     emit viewRemoved(widget);
@@ -455,7 +469,8 @@ TabbedViewContainerV2::TabbedViewContainerV2(NavigationPosition position , QObje
     _tabBar->setDrawBase(true);
    
     connect( _tabBar , SIGNAL(currentChanged(int)) , this , SLOT(currentTabChanged(int)) );
-    connect( _tabBar , SIGNAL(mouseDoubleClick(int)) , this , SLOT(tabDoubleClicked(int)) );
+    connect( _tabBar , SIGNAL(tabDoubleClicked(int)) , this , SLOT(tabDoubleClicked(int)) );
+    connect( _tabBar , SIGNAL(newTabRequest()) , this , SIGNAL(newViewRequest()) );
 
     _layout = new TabbedViewContainerV2Layout;
     _layout->setSpacing(0);
@@ -556,12 +571,7 @@ TabbedViewContainerV2::~TabbedViewContainerV2()
 }
 void TabbedViewContainerV2::tabDoubleClicked(int tab)
 {
-    qDebug() << __FUNCTION__ << ", tab index =" << tab;
-
-    if ( tab < 0 )
-    {
-        //emit duplicateRequest(); 
-    }
+    viewProperties( views()[tab] )->rename();
 }
 void TabbedViewContainerV2::moveViewWidget( int fromIndex , int toIndex )
 {
@@ -636,10 +646,11 @@ void TabbedViewContainerV2::removeViewWidget( QWidget* view )
 
 void TabbedViewContainerV2::setTabActivity(int index , bool activity)
 {
-    KColorScheme colorScheme;
+    const QPalette& palette = _tabBar->palette();
+    KColorScheme colorScheme(palette.currentColorGroup());
     const QColor colorSchemeActive = colorScheme.foreground(KColorScheme::ActiveText).color();    
     
-    const QColor normalColor = _tabBar->palette().text().color();
+    const QColor normalColor = palette.text().color();
     const QColor activityColor = KColorUtils::mix(normalColor,colorSchemeActive); 
 
 
@@ -684,14 +695,14 @@ void TabbedViewContainerV2::updateIcon(ViewProperties* item)
     }
 }
 
-StackedViewContainer::StackedViewContainer(NavigationPosition position , QObject* parent) 
-: ViewContainer(position,parent)
+StackedViewContainer::StackedViewContainer(QObject* parent) 
+: ViewContainer(NavigationPositionTop,parent)
 {
     _stackWidget = new QStackedWidget;
 }
 StackedViewContainer::~StackedViewContainer()
 {
-    delete _stackWidget;
+    _stackWidget->deleteLater();
 }
 QWidget* StackedViewContainer::containerWidget() const
 {
@@ -711,6 +722,10 @@ void StackedViewContainer::addViewWidget( QWidget* view )
 }
 void StackedViewContainer::removeViewWidget( QWidget* view )
 {
+    const int index = _stackWidget->indexOf(view);
+
+    Q_ASSERT( index != -1);
+
     _stackWidget->removeWidget(view);
 }
 
