@@ -35,7 +35,6 @@
 #include <KXMLGUIFactory>
 
 // Konsole
-#include "BookmarkHandler.h"
 #include "ColorScheme.h"
 #include "Session.h"
 #include "TerminalDisplay.h"
@@ -51,6 +50,7 @@ ViewManager::ViewManager(QObject* parent , KActionCollection* collection)
     , _viewSplitter(0)
     , _actionCollection(collection)
     , _containerSignalMapper(new QSignalMapper(this))
+    , _navigationMethod(TabbedNavigation)
 {
     // create main view area
     _viewSplitter = new ViewSplitter(0);   
@@ -61,6 +61,7 @@ ViewManager::ViewManager(QObject* parent , KActionCollection* collection)
     // the ViewManager class is not currently able to handle a ViewSplitter in recursive-splitting
     // mode 
     _viewSplitter->setRecursiveSplitting(false);
+    _viewSplitter->setFocusPolicy(Qt::NoFocus);
 
     // setup actions which relating to the view
     setupActions();
@@ -294,10 +295,6 @@ void ViewManager::sessionFinished()
 
     Q_ASSERT(session);
 
-    // record the size of the last session
-    //qDebug() << "Recording session size: " << session->size();
-    //setDefaultDisplaySize( session->size().height() , session->size().width() );
-
     // close attached views
     QList<TerminalDisplay*> children = _viewSplitter->findChildren<TerminalDisplay*>();
 
@@ -397,6 +394,15 @@ void ViewManager::removeContainer(ViewContainer* container)
     // so we take the previous container count and work out what the new count
     // would be.
     int previousCount = _viewSplitter->containers().count();
+
+    // remove session map entries for views in this container
+    foreach( QWidget* view , container->views() )
+    {
+        TerminalDisplay* display = qobject_cast<TerminalDisplay*>(view);
+        Q_ASSERT(display);
+        _sessionMap.remove(display);
+    } 
+
     container->deleteLater();
     emit splitViewToggle( (previousCount-1) > 1);
 }
@@ -475,13 +481,6 @@ void ViewManager::createView(Session* session)
         applyProfile(display,session->profileKey());
         
         // set initial size
-#if 0
-        int defaultLines = 0;
-        int defaultColumns = 0;
-        getDefaultDisplaySize(defaultLines,defaultColumns);
-        qDebug() << "Setting default display size to " << QSize(defaultColumns,defaultLines);
-        display->setSize(defaultColumns,defaultLines);
-#endif
         display->setSize(80,40);
 
         ViewProperties* properties = createController(session,display);
@@ -501,21 +500,6 @@ void ViewManager::createView(Session* session)
     }
 }
 
-#if 0
-void ViewManager::getDefaultDisplaySize(int& lines , int& columns) const
-{
-    const KConfigGroup group = KGlobal::config()->group("Last Session");
-    QSize size = group.readEntry("WindowSize",QSize(80,40));
-    lines = size.height();
-    columns = size.width();
-}
-void ViewManager::setDefaultDisplaySize(int lines , int columns)
-{
-    KConfigGroup group = KGlobal::config()->group("Last Session");
-    group.writeEntry("WindowSize",QSize(columns,lines));
-}
-#endif
-
 ViewContainer* ViewManager::createContainer(const QString& profileKey)
 {
     const Profile* info = SessionManager::instance()->profile(profileKey);
@@ -528,7 +512,17 @@ ViewContainer* ViewManager::createContainer(const QString& profileKey)
                                                    ViewContainer::NavigationPositionTop :
                                                    ViewContainer::NavigationPositionBottom;
 
-    ViewContainer* container = new TabbedViewContainerV2(position,_viewSplitter);
+    ViewContainer* container = 0;
+
+    switch ( _navigationMethod )
+    {
+        case TabbedNavigation:    
+            container = new TabbedViewContainerV2(position,_viewSplitter);
+            break;
+        case NoNavigation:
+        default:
+            container = new StackedViewContainer(_viewSplitter);
+    }
 
     // connect signals and slots
     connect( container , SIGNAL(viewAdded(QWidget*,ViewProperties*)) , _containerSignalMapper ,
@@ -537,6 +531,7 @@ ViewContainer* ViewManager::createContainer(const QString& profileKey)
            SLOT(map()) ); 
     _containerSignalMapper->setMapping(container,container);
 
+    connect( container, SIGNAL(newViewRequest()), this , SIGNAL(newViewRequest()) );
     connect( container , SIGNAL(viewRemoved(QWidget*)) , this , SLOT(viewCloseRequest(QWidget*)) );
     connect( container , SIGNAL(closeRequest(QWidget*)) , this , SLOT(viewCloseRequest(QWidget*)) );
     connect( container , SIGNAL(activeViewChanged(QWidget*)) , this , SLOT(viewActivated(QWidget*)));
@@ -544,6 +539,9 @@ ViewContainer* ViewManager::createContainer(const QString& profileKey)
     return container;
 }
 
+void ViewManager::setNavigationMethod(NavigationMethod method) { _navigationMethod = method; }
+ViewManager::NavigationMethod ViewManager::navigationMethod() const { return _navigationMethod; }
+
 void ViewManager::containerViewsChanged(QObject* container)
 {
     //qDebug() << "Container views changed";
@@ -614,7 +612,7 @@ void ViewManager::applyProfile(TerminalDisplay* view , const QString& profileKey
     const ColorScheme* colorScheme = colorSchemeForProfile(profileKey);
 
     // menu bar visibility
-    emit setMenuBarVisible( info->property(Profile::ShowMenuBar).value<bool>() );
+    emit setMenuBarVisibleRequest( info->property(Profile::ShowMenuBar).value<bool>() );
 
     // tab bar visibility
     ViewContainer* container = _viewSplitter->activeContainer();
@@ -628,10 +626,15 @@ void ViewManager::applyProfile(TerminalDisplay* view , const QString& profileKey
     else if ( tabBarMode == Profile::ShowTabBarAsNeeded )
         container->setNavigationDisplayMode(ViewContainer::ShowNavigationAsNeeded);
 
+    ViewContainer::NavigationPosition position = container->navigationPosition();
+
     if ( tabBarPosition == Profile::TabBarTop )
-        container->setNavigationPosition(ViewContainer::NavigationPositionTop);
+        position = ViewContainer::NavigationPositionTop;
     else if ( tabBarPosition == Profile::TabBarBottom )
-        container->setNavigationPosition(ViewContainer::NavigationPositionBottom);
+        position = ViewContainer::NavigationPositionBottom; 
+
+    if ( container->supportedNavigationPositions().contains(position) )
+        container->setNavigationPosition(position);
 
     // load colour scheme
     ColorEntry table[TABLE_COLORS];
