@@ -442,7 +442,7 @@ bool KIO_Print::getDBFile( const KUrl& src )
 	m_httpBuffer.open( QIODevice::WriteOnly|QIODevice::Truncate ); // be sure to erase the existing data
 
 	/* start the transfer job */
-	KIO::TransferJob *job = KIO::get( src, false, false );
+	KIO::TransferJob *job = KIO::get( src, KIO::NoReload, KIO::HideProgressInfo );
 	connect( job, SIGNAL( result( KJob* ) ), SLOT( slotResult( KJob* ) ) );
 	connect( job, SIGNAL( data( KIO::Job*, const QByteArray& ) ), SLOT( slotData( KIO::Job*, const QByteArray& ) ) );
 	connect( job, SIGNAL( totalSize( KJob*, qulonglong ) ), SLOT( slotTotalSize( KJob*, qulonglong ) ) );
@@ -792,7 +792,7 @@ QString KIO_Print::locateData(const QString& item)
 {
 	QString	path = KStandardDirs::locate("data", "kdeprint/template/"+item);
 	if (path.isEmpty())
-		path = KIconLoader::global()->iconPath(item, K3Icon::Desktop, true);
+		path = KIconLoader::global()->iconPath(item, KIconLoader::Desktop, true);
 	return path;
 }
 
