@@ -382,7 +382,7 @@ bool TrashImpl::move( const QString& src, const QString& dest )
     urlSrc.setPath( src );
     urlDest.setPath( dest );
     kDebug() << urlSrc << " -> " << urlDest;
-    KIO::CopyJob* job = KIO::moveAs( urlSrc, urlDest, false );
+    KIO::CopyJob* job = KIO::moveAs( urlSrc, urlDest, KIO::HideProgressInfo );
     job->setUiDelegate(0);
     connect( job, SIGNAL( result(KJob*) ),
              this, SLOT( jobFinished(KJob*) ) );
@@ -427,7 +427,7 @@ bool TrashImpl::copy( const QString& src, const QString& dest )
     KUrl urlDest;
     urlDest.setPath( dest );
     kDebug() << "copying " << src << " to " << dest;
-    KIO::CopyJob* job = KIO::copyAs( urlSrc, urlDest, false );
+    KIO::CopyJob* job = KIO::copyAs( urlSrc, urlDest, KIO::HideProgressInfo );
     job->setUiDelegate(0);
     connect( job, SIGNAL( result(KJob*) ),
              this, SLOT( jobFinished(KJob*) ) );
@@ -515,14 +515,14 @@ bool TrashImpl::synchronousDel( const QString& path, bool setLastErrorCode, bool
         kDebug() << "chmod'ing " << url;
         KFileItem fileItem( url, "inode/directory", KFileItem::Unknown );
         KFileItemList fileItemList;
-        fileItemList.append( &fileItem );
-        KIO::ChmodJob* chmodJob = KIO::chmod( fileItemList, 0200, 0200, QString(), QString(), true /*recursive*/, false /*showProgressInfo*/ );
+        fileItemList.append( fileItem );
+        KIO::ChmodJob* chmodJob = KIO::chmod( fileItemList, 0200, 0200, QString(), QString(), true /*recursive*/, KIO::HideProgressInfo );
         connect( chmodJob, SIGNAL( result(KJob *) ),
                  this, SLOT( jobFinished(KJob *) ) );
         enterLoop();
     }
 
-    KIO::DeleteJob *job = KIO::del( url, false, false );
+    KIO::DeleteJob *job = KIO::del( url, KIO::HideProgressInfo );
     connect( job, SIGNAL( result(KJob*) ),
              this, SLOT( jobFinished(KJob*) ) );
     enterLoop();
@@ -615,7 +615,7 @@ bool TrashImpl::infoForFile( int trashId, const QString& fileId, TrashedFileInfo
 
 bool TrashImpl::readInfoFile( const QString& infoPath, TrashedFileInfo& info, int trashId )
 {
-    KConfig cfg( infoPath, KConfig::OnlyLocal);
+    KConfig cfg( infoPath, KConfig::SimpleConfig);
     if ( !cfg.hasGroup( "Trash Info" ) ) {
         error( KIO::ERR_CANNOT_OPEN_FOR_READING, infoPath );
         return false;
