@@ -36,6 +36,7 @@
 #include <kprotocolinfo.h>
 #include <kstandarddirs.h>
 #include <kconfig.h>
+#include <kconfiggroup.h>
 #include <kauthorized.h>
 #include <kmimetype.h>
 
@@ -86,11 +87,12 @@ static bool isValidShortURL( const QString& cmd, bool verbose = false )
     if (verbose)
       kDebug() << "KShortURIFilter::isValidShortURL: " << cmd
                 << " matches FQDN_PATTERN" << endl;
-
+#if 0
     // something like wallpaper.png also matches a the FQDN pattern
     // but is very unlikely to be meant as such
     if (KMimeType::findByPath(cmd) != KMimeType::defaultMimeTypePtr())
         return false;
+#endif
 
     return true;
   }
@@ -146,7 +148,7 @@ static QString removeArgs( const QString& _cmd )
   return cmd;
 }
 
-KShortUriFilter::KShortUriFilter( QObject *parent, const QStringList & /*args*/ )
+KShortUriFilter::KShortUriFilter( QObject *parent, const QVariantList & /*args*/ )
                 :KUriFilterPlugin( "kshorturifilter", parent )
 {
     QDBusConnection::sessionBus().connect(QString(), QString(), "org.kde.KUriFilterPlugin",
@@ -185,7 +187,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
      // Handle "encrypted" URLs like: h++p://www.kde.org
      url.setProtocol( QLatin1String("http"));
      setFilteredUri( data, url);
-     setUriType( data, KUriFilterData::NET_PROTOCOL );
+     setUriType( data, KUriFilterData::NetProtocol );
      return true;
   }
 
@@ -198,7 +200,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
   if (cmd.indexOf(starthere_proto) == 0 )
   {
     setFilteredUri( data, KUrl("system:/") );
-    setUriType( data, KUriFilterData::LOCAL_DIR );
+    setUriType( data, KUriFilterData::LocalDir );
     return true;
   }
 
@@ -218,7 +220,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
       cmd+='/';
 
     setFilteredUri( data, KUrl( cmd ));
-    setUriType( data, KUriFilterData::HELP );
+    setUriType( data, KUriFilterData::Help );
     return true;
   }
 
@@ -229,7 +231,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     cmd.replace('\\', '/');
     cmd.prepend( QLatin1String( "smb:" ) );
     setFilteredUri( data, KUrl( cmd ));
-    setUriType( data, KUriFilterData::NET_PROTOCOL );
+    setUriType( data, KUriFilterData::NetProtocol );
     return true;
   }
 
@@ -292,7 +294,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
         QString msg = dir ? i18n("<qt><b>%1</b> does not have a home folder.</qt>", user) :
                             i18n("<qt>There is no user called <b>%1</b>.</qt>", user);
         setErrorMsg( data, msg );
-        setUriType( data, KUriFilterData::ERROR );
+        setUriType( data, KUriFilterData::Error );
         // Always return true for error conditions so
         // that other filters will not be invoked !!
         return true;
@@ -408,7 +410,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
       // No authorisation, we pretend it's a file will get
       // an access denied error later on.
       setFilteredUri( data, u );
-      setUriType( data, KUriFilterData::LOCAL_FILE );
+      setUriType( data, KUriFilterData::LocalFile );
       return true;
     }
 
@@ -418,7 +420,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     {
       //kDebug() << "Abs path to EXECUTABLE";
       setFilteredUri( data, u );
-      setUriType( data, KUriFilterData::EXECUTABLE );
+      setUriType( data, KUriFilterData::Executable );
       return true;
     }
 
@@ -429,7 +431,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
       if ( !nameFilter.isEmpty() )
         u.setFileName( nameFilter );
       setFilteredUri( data, u );
-      setUriType( data, ( isDir ) ? KUriFilterData::LOCAL_DIR : KUriFilterData::LOCAL_FILE );
+      setUriType( data, ( isDir ) ? KUriFilterData::LocalDir : KUriFilterData::LocalFile );
       return true;
     }
 
@@ -450,7 +452,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     // check if we have command line arguments
     if( exe != cmd )
         setArguments(data, cmd.right(cmd.length() - exe.length()));
-    setUriType( data, KUriFilterData::EXECUTABLE );
+    setUriType( data, KUriFilterData::Executable );
     return true;
   }
 
@@ -464,9 +466,9 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     {
       setFilteredUri( data, url );
       if ( protocol == QFL1("man") || protocol == QFL1("help") )
-        setUriType( data, KUriFilterData::HELP );
+        setUriType( data, KUriFilterData::Help );
       else
-        setUriType( data, KUriFilterData::NET_PROTOCOL );
+        setUriType( data, KUriFilterData::NetProtocol );
       return true;
     }
   }
@@ -500,7 +502,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
 
       cmd.insert( 0, m_strDefaultProtocol );
       setFilteredUri( data, KUrl( cmd ));
-      setUriType( data, KUriFilterData::NET_PROTOCOL );
+      setUriType( data, KUriFilterData::NetProtocol );
       return true;
     }
   }
@@ -518,12 +520,12 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
       // No authorisation, we pretend it exists and will get
       // an access denied error later on.
       setFilteredUri( data, u );
-      setUriType( data, KUriFilterData::LOCAL_FILE );
+      setUriType( data, KUriFilterData::LocalFile );
       return true;
     }
     //kDebug() << "fileNotFound -> ERROR";
     setErrorMsg( data, i18n( "<qt>The file or folder <b>%1</b> does not exist.</qt>", data.uri().prettyUrl() ) );
-    setUriType( data, KUriFilterData::ERROR );
+    setUriType( data, KUriFilterData::Error );
     return true;
   }
 
@@ -544,7 +546,7 @@ QString KShortUriFilter::configName() const
 
 void KShortUriFilter::configure()
 {
-  KConfig config( objectName() + QFL1( "rc"), KConfig::NoGlobals );
+  KConfig config( objectName() + QFL1( "rc"), KConfig::CascadeConfig );
   KConfigGroup cg( config.group("") );
   m_bVerbose = cg.readEntry( "Verbose", false );
 
@@ -562,7 +564,7 @@ void KShortUriFilter::configure()
     if (!protocol.isEmpty())
     {
       int type = typeGroup.readEntry(it.key(), -1);
-      if (type > -1 && type <= KUriFilterData::UNKNOWN)
+      if (type > -1 && type <= KUriFilterData::Unknown)
         m_urlHints.append( URLHint(it.value(), protocol, static_cast<KUriFilterData::UriTypes>(type) ) );
       else
         m_urlHints.append( URLHint(it.value(), protocol) );
@@ -570,7 +572,7 @@ void KShortUriFilter::configure()
   }
 }
 
-K_EXPORT_COMPONENT_FACTORY( libkshorturifilter,
-                            KGenericFactory<KShortUriFilter>( "kcmkurifilt" ) )
+K_PLUGIN_FACTORY(KShortUriFilterFactory, registerPlugin<KShortUriFilter>();)
+K_EXPORT_PLUGIN(KShortUriFilterFactory("kcmkurifilt"))
 
 #include "kshorturifilter.moc"
