@@ -36,6 +36,9 @@ class XineOptions : public KCModule, private Ui::XineOptions
         void save();
         void defaults();
 
+    private slots:
+        void ossCheckboxToggled(bool b);
+
     private:
         KSharedConfigPtr m_config;
 };
