@@ -352,13 +352,13 @@ void MediaObject::handleFinished()
 MediaSource MediaObject::source() const
 {
     //kDebug(610);
-	return m_mediaSource;
+    return m_mediaSource;
 }
 
 qint32 MediaObject::prefinishMark() const
 {
     //kDebug(610);
-	return m_prefinishMark;
+    return m_prefinishMark;
 }
 
 qint32 MediaObject::transitionTime() const
@@ -373,8 +373,7 @@ void MediaObject::setTransitionTime(qint32 newTransitionTime)
         if (m_transitionTime == 0) {
             stream().useGaplessPlayback(true);
         } else if (m_transitionTime > 0) {
-            // TODO: a gap of m_transitionTime milliseconds
-            stream().useGaplessPlayback(true);
+            stream().useGapOf((newTransitionTime + 50) / 100); // xine-lib provides a resolution of 1/10s
         } else {
             // TODO: a crossfade of milliseconds milliseconds
             stream().useGaplessPlayback(true);
@@ -384,18 +383,23 @@ void MediaObject::setTransitionTime(qint32 newTransitionTime)
 
 void MediaObject::setNextSource(const MediaSource &source)
 {
+    if (m_transitionTime < 0) {
+        kError(610) << "crossfades are not supported with the xine backend";
+    } else if (m_transitionTime > 0) {
+        if (source.type() == MediaSource::Invalid) {
+            QMetaObject::invokeMethod(m_stream, "playbackFinished", Qt::QueuedConnection);
+        } else {
+            setSourceInternal(source, HardSwitch);
+            play();
+        }
+        return;
+    }
     if (source.type() == MediaSource::Invalid) {
         // the frontend is telling us that the play-queue is empty, so stop waiting for a new MRL
         // for gapless playback
         m_stream->gaplessSwitchTo(QByteArray());
-        setSourceInternal(m_mediaSource, HardSwitch);
         return;
     }
-    if (m_transitionTime < 0) {
-        kError(610) << "crossfades are not supported with the xine backend";
-    } else if (m_transitionTime > 0) {
-        kError(610) << "defined gaps are not supported with the xine backend";
-    }
     setSourceInternal(source, GaplessSwitch);
 }
 
@@ -445,21 +449,21 @@ void MediaObject::setSourceInternal(const MediaSource &source, HowToSetTheUrl ho
 
             QByteArray mrl;
             switch (source.discType()) {
-                case Phonon::NoDisc:
-                    kFatal(610) << "I should never get to see a MediaSource that is a disc but doesn't specify which one";
-                    return;
-                case Phonon::Cd:
-                    mrl = autoplayMrlsToTitles("CD", "cdda:/");
-                    break;
-                case Phonon::Dvd:
-                    mrl = "dvd:" + m_mediaDevice;
-                    break;
-                case Phonon::Vcd:
-                    mrl = autoplayMrlsToTitles("VCD", "vcd:/");
-                    break;
-                default:
-                    kError(610) << "media " << source.discType() << " not implemented";
-                    return;
+            case Phonon::NoDisc:
+                kFatal(610) << "I should never get to see a MediaSource that is a disc but doesn't specify which one";
+                return;
+            case Phonon::Cd:
+                mrl = autoplayMrlsToTitles("CD", "cdda:/");
+                break;
+            case Phonon::Dvd:
+                mrl = "dvd:" + m_mediaDevice;
+                break;
+            case Phonon::Vcd:
+                mrl = autoplayMrlsToTitles("VCD", "vcd:/");
+                break;
+            default:
+                kError(610) << "media " << source.discType() << " not implemented";
+                return;
             }
             switch (how) {
             case GaplessSwitch:
@@ -657,7 +661,7 @@ void MediaObject::needNextUrl()
     emit aboutToFinish();
 }
 
-void MediaObject::setPrefinishMark( qint32 newPrefinishMark )
+void MediaObject::setPrefinishMark(qint32 newPrefinishMark)
 {
     m_prefinishMark = newPrefinishMark;
     stream().setPrefinishMark(newPrefinishMark);
