@@ -20,9 +20,9 @@
 
 #include "xineengine.h"
 
-//#include <kdebug.h>
 #include "mediaobject.h"
 #include <QCoreApplication>
+#include <QtDBus/QDBusConnection>
 #include <phonon/audiodeviceenumerator.h>
 #include <phonon/audiodevice.h>
 #include <QList>
@@ -33,6 +33,7 @@
 #include "backend.h"
 #include "events.h"
 #include "xinethread.h"
+#include <xineengine_padaptor.h>
 
 namespace Phonon
 {
@@ -42,6 +43,8 @@ namespace Xine
     {
         signalTimer.setSingleShot(true);
         connect(&signalTimer, SIGNAL(timeout()), SLOT(emitAudioDeviceChange()));
+        new XineEnginePrivateAdaptor(this);
+        QDBusConnection::sessionBus().registerObject("/internal/PhononXine", this);
     }
 
     void XineEnginePrivate::emitAudioDeviceChange()
@@ -52,9 +55,10 @@ namespace Xine
 
     static XineEngine *s_instance = 0;
 
-    XineEngine::XineEngine(const KSharedConfigPtr& _config)
+    XineEngine::XineEngine(const KSharedConfigPtr &_config)
         : m_xine(xine_new()),
         m_config(_config),
+        m_useOss(XineEngine::Unknown),
         d(new XineEnginePrivate),
         m_nullPort(0),
         m_nullVideoPort(0),
@@ -63,7 +67,7 @@ namespace Xine
         Q_ASSERT(s_instance == 0);
         s_instance = this;
         KConfigGroup cg(m_config, "Settings");
-        m_useOss = cg.readEntry("showOssDevices", false);
+
         m_deinterlaceDVD = cg.readEntry("deinterlaceDVD", true);
         m_deinterlaceVCD = cg.readEntry("deinterlaceVCD", false);
         m_deinterlaceFile = cg.readEntry("deinterlaceFile", false);
@@ -110,10 +114,10 @@ namespace Xine
         return self()->d;
     }
 
-	xine_t* XineEngine::xine()
-	{
-		return self()->m_xine;
-	}
+    xine_t *XineEngine::xine()
+    {
+        return self()->m_xine;
+    }
 
     XineThread *XineEngine::thread()
     {
@@ -152,83 +156,83 @@ namespace Xine
         if (!p || !xineEvent) {
             return;
         }
-        //kDebug( 610 ) << "Xine event: " << xineEvent->type << QByteArray((char *)xineEvent->data, xineEvent->data_length);
+        //kDebug(610) << "Xine event: " << xineEvent->type << QByteArray((char *)xineEvent->data, xineEvent->data_length);
 
         XineStream *xs = static_cast<XineStream *>(p);
 
         switch (xineEvent->type) {
-            case XINE_EVENT_UI_SET_TITLE: /* request title display change in ui */
-                QCoreApplication::postEvent(xs, new QEVENT(NewMetaData));
-                break;
-            case XINE_EVENT_UI_PLAYBACK_FINISHED: /* frontend can e.g. move on to next playlist entry */
-                QCoreApplication::postEvent(xs, new QEVENT(MediaFinished));
-                break;
-            case XINE_EVENT_PROGRESS: /* index creation/network connections */
-                {
-                    xine_progress_data_t *progress = static_cast<xine_progress_data_t*>(xineEvent->data);
-                    QCoreApplication::postEvent(xs, new ProgressEvent(QString::fromUtf8(progress->description), progress->percent));
+        case XINE_EVENT_UI_SET_TITLE: /* request title display change in ui */
+            QCoreApplication::postEvent(xs, new QEVENT(NewMetaData));
+            break;
+        case XINE_EVENT_UI_PLAYBACK_FINISHED: /* frontend can e.g. move on to next playlist entry */
+            QCoreApplication::postEvent(xs, new QEVENT(MediaFinished));
+            break;
+        case XINE_EVENT_PROGRESS: /* index creation/network connections */
+            {
+                xine_progress_data_t *progress = static_cast<xine_progress_data_t *>(xineEvent->data);
+                QCoreApplication::postEvent(xs, new ProgressEvent(QString::fromUtf8(progress->description), progress->percent));
+            }
+            break;
+        case XINE_EVENT_SPU_BUTTON: // the mouse pointer enter/leave a button, used to change the cursor
+            {
+                xine_spu_button_t *button = static_cast<xine_spu_button_t *>(xineEvent->data);
+                if (button->direction == 1) { // enter a button
+                    xs->handleDownstreamEvent(new QEVENT(NavButtonIn));
+                } else {
+                    xs->handleDownstreamEvent(new QEVENT(NavButtonOut));
                 }
-                break;
-            case XINE_EVENT_SPU_BUTTON: // the mouse pointer enter/leave a button, used to change the cursor
-                {
-                    xine_spu_button_t *button = static_cast<xine_spu_button_t *>(xineEvent->data);
-                    if (button->direction == 1) { // enter a button
-                        xs->handleDownstreamEvent(new QEVENT(NavButtonIn));
-                    } else {
-                        xs->handleDownstreamEvent(new QEVENT(NavButtonOut));
-                    }
+            }
+            break;
+        case XINE_EVENT_UI_CHANNELS_CHANGED:    /* inform ui that new channel info is available */
+            kDebug(610) << "XINE_EVENT_UI_CHANNELS_CHANGED";
+            {
+                QCoreApplication::postEvent(xs, new QEVENT(UiChannelsChanged));
+            }
+            break;
+        case XINE_EVENT_UI_MESSAGE:             /* message (dialog) for the ui to display */
+            {
+                kDebug(610) << "XINE_EVENT_UI_MESSAGE";
+                const xine_ui_message_data_t *message = static_cast<xine_ui_message_data_t *>(xineEvent->data);
+                if (message->type == XINE_MSG_AUDIO_OUT_UNAVAILABLE) {
+                    kDebug(610) << "XINE_MSG_AUDIO_OUT_UNAVAILABLE";
+                    // we don't know for sure which AudioOutput failed. but the one without any
+                    // capabilities must be the guilty one
+                    xs->handleDownstreamEvent(new QEVENT(AudioDeviceFailed));
                 }
-                break;
-            case XINE_EVENT_UI_CHANNELS_CHANGED:    /* inform ui that new channel info is available */
-                kDebug(610) << "XINE_EVENT_UI_CHANNELS_CHANGED";
-                {
-                    QCoreApplication::postEvent(xs, new QEVENT(UiChannelsChanged));
-                }
-                break;
-            case XINE_EVENT_UI_MESSAGE:             /* message (dialog) for the ui to display */
-                {
-                    kDebug(610) << "XINE_EVENT_UI_MESSAGE";
-                    const xine_ui_message_data_t *message = static_cast<xine_ui_message_data_t *>(xineEvent->data);
-                    if (message->type == XINE_MSG_AUDIO_OUT_UNAVAILABLE) {
-                        kDebug(610) << "XINE_MSG_AUDIO_OUT_UNAVAILABLE";
-                        // we don't know for sure which AudioOutput failed. but the one without any
-                        // capabilities must be the guilty one
-                        xs->handleDownstreamEvent(new QEVENT(AudioDeviceFailed));
-                    }
-                }
-                break;
-            case XINE_EVENT_FRAME_FORMAT_CHANGE:    /* e.g. aspect ratio change during dvd playback */
-                kDebug(610) << "XINE_EVENT_FRAME_FORMAT_CHANGE";
-                {
-                    xine_format_change_data_t *data = static_cast<xine_format_change_data_t *>(xineEvent->data);
-                    xs->handleDownstreamEvent(new FrameFormatChangeEvent(data->width, data->height, data->aspect, data->pan_scan));
-                }
-                break;
-            case XINE_EVENT_AUDIO_LEVEL:            /* report current audio level (l/r/mute) */
-                kDebug(610) << "XINE_EVENT_AUDIO_LEVEL";
-                break;
-            case XINE_EVENT_QUIT:                   /* last event sent when stream is disposed */
-                kDebug(610) << "XINE_EVENT_QUIT";
-                break;
-            case XINE_EVENT_UI_NUM_BUTTONS:         /* number of buttons for interactive menus */
-                kDebug(610) << "XINE_EVENT_UI_NUM_BUTTONS";
-                break;
-            case XINE_EVENT_DROPPED_FRAMES:         /* number of dropped frames is too high */
-                kDebug(610) << "XINE_EVENT_DROPPED_FRAMES";
-                break;
-            case XINE_EVENT_MRL_REFERENCE_EXT:      /* demuxer->frontend: MRL reference(s) for the real stream */
-                {
-                    xine_mrl_reference_data_ext_t *reference = static_cast<xine_mrl_reference_data_ext_t *>(xineEvent->data);
-                    kDebug(610) << "XINE_EVENT_MRL_REFERENCE_EXT: " << reference->alternative
-                        << ", " << reference->start_time
-                        << ", " << reference->duration
-                        << ", " << reference->mrl
-                        << ", " << (reference->mrl + strlen(reference->mrl) + 1)
-                        ;
-                    QCoreApplication::postEvent(xs, new ReferenceEvent(reference->alternative, reference->mrl));
-                }
-                break;
-        }
+            }
+            break;
+        case XINE_EVENT_FRAME_FORMAT_CHANGE:    /* e.g. aspect ratio change during dvd playback */
+            kDebug(610) << "XINE_EVENT_FRAME_FORMAT_CHANGE";
+            {
+                xine_format_change_data_t *data = static_cast<xine_format_change_data_t *>(xineEvent->data);
+                xs->handleDownstreamEvent(new FrameFormatChangeEvent(data->width, data->height, data->aspect, data->pan_scan));
+            }
+            break;
+        case XINE_EVENT_AUDIO_LEVEL:            /* report current audio level (l/r/mute) */
+            kDebug(610) << "XINE_EVENT_AUDIO_LEVEL";
+            break;
+        case XINE_EVENT_QUIT:                   /* last event sent when stream is disposed */
+            kDebug(610) << "XINE_EVENT_QUIT";
+            break;
+        case XINE_EVENT_UI_NUM_BUTTONS:         /* number of buttons for interactive menus */
+            kDebug(610) << "XINE_EVENT_UI_NUM_BUTTONS";
+            break;
+        case XINE_EVENT_DROPPED_FRAMES:         /* number of dropped frames is too high */
+            kDebug(610) << "XINE_EVENT_DROPPED_FRAMES";
+            break;
+        case XINE_EVENT_MRL_REFERENCE_EXT:      /* demuxer->frontend: MRL reference(s) for the real stream */
+            {
+                xine_mrl_reference_data_ext_t *reference = static_cast<xine_mrl_reference_data_ext_t *>(xineEvent->data);
+                kDebug(610) << "XINE_EVENT_MRL_REFERENCE_EXT: " << reference->alternative
+                    << ", " << reference->start_time
+                    << ", " << reference->duration
+                    << ", " << reference->mrl
+                    << ", " << (reference->mrl + strlen(reference->mrl) + 1)
+                    ;
+                QCoreApplication::postEvent(xs, new ReferenceEvent(reference->alternative, reference->mrl));
+            }
+            break;
+    }
     }
 
     xine_audio_port_t *XineEngine::nullPort()
@@ -255,9 +259,7 @@ namespace Xine
         that->checkAudioOutputs();
         QSet<int> set;
         for (int i = 0; i < that->m_audioOutputInfos.size(); ++i) {
-            //if (that->m_audioOutputInfos[i].available) {
-                set << that->m_audioOutputInfos[i].index;
-            //}
+            set << that->m_audioOutputInfos[i].index;
         }
         return set;
     }
@@ -268,7 +270,18 @@ namespace Xine
         that->checkAudioOutputs();
         for (int i = 0; i < that->m_audioOutputInfos.size(); ++i) {
             if (that->m_audioOutputInfos[i].index == audioDevice) {
-                return that->m_audioOutputInfos[i].name;
+                switch (that->m_useOss) {
+                case XineEngine::True: // postfix
+                    if (that->m_audioOutputInfos[i].driver == "oss") {
+                        return i18n("%1 (OSS)", that->m_audioOutputInfos[i].name);
+                    } else if (that->m_audioOutputInfos[i].driver == "alsa") {
+                        return i18n("%1 (ALSA)", that->m_audioOutputInfos[i].name);
+                    }
+                    // no postfix: fall through
+                case XineEngine::False: // no postfix
+                case XineEngine::Unknown: // no postfix
+                    return that->m_audioOutputInfos[i].name;
+                }
             }
         }
         return QString();
@@ -309,7 +322,35 @@ namespace Xine
         return false;
     }
 
-    QString XineEngine::audioDriverFor(int audioDevice)
+    QVariant XineEngine::audioOutputMixerDevice(int audioDevice)
+    {
+        XineEngine *that = self();
+        that->checkAudioOutputs();
+        for (int i = 0; i < that->m_audioOutputInfos.size(); ++i) {
+            if (that->m_audioOutputInfos[i].index == audioDevice) {
+                if (that->m_audioOutputInfos[i].driver == "alsa") {
+                    return that->m_audioOutputInfos[i].mixerDevice;
+                }
+                break;
+            }
+        }
+        return QVariant();
+    }
+
+    int XineEngine::audioOutputInitialPreference(int audioDevice)
+    {
+        XineEngine *that = self();
+        that->checkAudioOutputs();
+
+        for (int i = 0; i < that->m_audioOutputInfos.size(); ++i) {
+            if (that->m_audioOutputInfos[i].index == audioDevice) {
+                return that->m_audioOutputInfos[i].initialPreference;
+            }
+        }
+        return 0;
+    }
+
+    QByteArray XineEngine::audioDriverFor(int audioDevice)
     {
         XineEngine *that = self();
         that->checkAudioOutputs();
@@ -318,7 +359,7 @@ namespace Xine
                 return that->m_audioOutputInfos[i].driver;
             }
         }
-        return QString();
+        return QByteArray();
     }
 
     QStringList XineEngine::alsaDevicesFor(int audioDevice)
@@ -335,23 +376,73 @@ namespace Xine
         return QStringList();
     }
 
-    void XineEngine::addAudioOutput(AudioDevice dev, QString driver)
+    void XineEnginePrivate::ossSettingChanged(bool useOss)
     {
-        QString postfix;
-        if (m_useOss) {
-            if (dev.driver() == Solid::AudioInterface::Alsa) {
-                postfix = QLatin1String(" (ALSA)");
-            } else if (dev.driver() == Solid::AudioInterface::OpenSoundSystem) {
-                postfix = QLatin1String(" (OSS)");
+        const XineEngine::UseOss tmp = useOss ? XineEngine::True : XineEngine::False;
+        if (tmp == s_instance->m_useOss) {
+            return;
+        }
+        s_instance->m_useOss = tmp;
+        if (useOss) {
+            // add OSS devices if xine supports OSS output
+            const char *const *outputPlugins = xine_list_audio_output_plugins(s_instance->xine());
+            for (int i = 0; outputPlugins[i]; ++i) {
+                if (0 == strcmp(outputPlugins[i], "oss")) {
+                    QList<AudioDevice> audioDevices = AudioDeviceEnumerator::availablePlaybackDevices();
+                    foreach (const AudioDevice &dev, audioDevices) {
+                        if (dev.driver() == Solid::AudioInterface::OpenSoundSystem) {
+                            s_instance->addAudioOutput(dev, "oss");
+                        }
+                    }
+                    signalTimer.start();
+                    return;
+                }
             }
+        } else {
+            // remove all OSS devices
+            typedef QList<XineEngine::AudioOutputInfo>::iterator Iterator;
+            Iterator it = s_instance->m_audioOutputInfos.begin();
+            while (it != s_instance->m_audioOutputInfos.end()) {
+                if (it->driver == "oss") {
+                    it = s_instance->m_audioOutputInfos.erase(it);
+                } else {
+                    ++it;
+                }
+            }
+            signalTimer.start();
+        }
+    }
+
+    void XineEngine::addAudioOutput(AudioDevice dev, const QByteArray &driver)
+    {
+        QString mixerDevice;
+        int initialPreference = dev.initialPreference();
+        if (dev.driver() == Solid::AudioInterface::Alsa) {
+            initialPreference += 100;
+            foreach (QString id, dev.deviceIds()) {
+                const int idx = id.indexOf(QLatin1String("CARD="));
+                if (idx > 0) {
+                    id = id.mid(idx + 5);
+                    const int commaidx = id.indexOf(QLatin1Char(','));
+                    if (commaidx > 0) {
+                        id = id.left(commaidx);
+                    }
+                    mixerDevice = QLatin1String("hw:") + id;
+                    break;
+                }
+                mixerDevice = id;
+            }
+        } else if (!dev.deviceIds().isEmpty()) {
+            initialPreference += 50;
+            mixerDevice = dev.deviceIds().first();
         }
         const QString description = dev.deviceIds().isEmpty() ?
             i18n("<html>This device is currently not available (either it is unplugged or the "
                     "driver is not loaded).</html>") :
             i18n("<html>This will try the following devices and use the first that works: "
                     "<ol><li>%1</li></ol></html>", dev.deviceIds().join("</li><li>"));
-        AudioOutputInfo info(dev.index(), dev.cardName() + postfix,
-                description, dev.iconName(), driver, dev.deviceIds());
+        AudioOutputInfo info(dev.index(), initialPreference, dev.cardName(),
+                description, dev.iconName(), driver, dev.deviceIds(), mixerDevice);
         info.available = dev.isAvailable();
         if (m_audioOutputInfos.contains(info)) {
             m_audioOutputInfos.removeAll(info); // the latest is more up to date wrt availability
@@ -359,68 +450,91 @@ namespace Xine
         m_audioOutputInfos << info;
     }
 
-    void XineEngine::addAudioOutput(int index, const QString &name, const QString &description,
-            const QString &icon, const QString &driver, const QStringList &deviceIds)
+    void XineEngine::addAudioOutput(int index, int initialPreference, const QString &name, const QString &description,
+            const QString &icon, const QByteArray &driver, const QStringList &deviceIds, const QString &mixerDevice)
     {
-        AudioOutputInfo info(index, name, description, icon, driver, deviceIds);
+        AudioOutputInfo info(index, initialPreference, name, description, icon, driver, deviceIds, mixerDevice);
         const int listIndex = m_audioOutputInfos.indexOf(info);
         if (listIndex == -1) {
             info.available = true;
             m_audioOutputInfos << info;
-            KConfigGroup config(m_config, QLatin1String("AudioOutputDevice_") + QString::number(index));
-            config.writeEntry("name", name);
-            config.writeEntry("description", description);
-            config.writeEntry("driver", driver);
-            config.writeEntry("icon", icon);
+//X             KConfigGroup config(m_config, QLatin1String("AudioOutputDevice_") + QString::number(index));
+//X             config.writeEntry("name", name);
+//X             config.writeEntry("description", description);
+//X             config.writeEntry("driver", driver);
+//X             config.writeEntry("icon", icon);
+//X             config.writeEntry("initialPreference", initialPreference);
         } else {
             AudioOutputInfo &infoInList = m_audioOutputInfos[listIndex];
-            if (infoInList.icon != icon) {
-                KConfigGroup config(m_config, QLatin1String("AudioOutputDevice_") + QString::number(infoInList.index));
-                config.writeEntry("icon", icon);
+            if (infoInList.icon != icon || infoInList.initialPreference != initialPreference) {
+//X                 KConfigGroup config(m_config, QLatin1String("AudioOutputDevice_") + QString::number(infoInList.index));
+
+//X                 config.writeEntry("icon", icon);
+//X                 config.writeEntry("initialPreference", initialPreference);
+
                 infoInList.icon = icon;
+                infoInList.initialPreference = initialPreference;
             }
             infoInList.devices = deviceIds;
+            infoInList.mixerDevice = mixerDevice;
             infoInList.available = true;
         }
     }
 
     void XineEngine::checkAudioOutputs()
     {
-        kDebug(610) ;
         if (m_audioOutputInfos.isEmpty()) {
             kDebug(610) << "isEmpty";
             QObject::connect(AudioDeviceEnumerator::self(), SIGNAL(devicePlugged(const AudioDevice &)),
                     d, SLOT(devicePlugged(const AudioDevice &)));
             QObject::connect(AudioDeviceEnumerator::self(), SIGNAL(deviceUnplugged(const AudioDevice &)),
                     d, SLOT(deviceUnplugged(const AudioDevice &)));
-            QStringList groups = m_config->groupList();
             int nextIndex = 10000;
-            foreach (QString group, groups) {
-                if (group.startsWith("AudioOutputDevice_")) {
-                    const int index = group.right(group.size() - 18/*strlen("AudioOutputDevice_")*/).toInt();
-                    if (index >= nextIndex) {
-                        nextIndex = index + 1;
-                    }
-                    KConfigGroup config(m_config, group);
-                    m_audioOutputInfos << AudioOutputInfo(index,
-                            config.readEntry("name", QString()),
-                            config.readEntry("description", QString()),
-                            config.readEntry("icon", QString()),
-                            config.readEntry("driver", QString()),
-                            QStringList()); // the device list can change and needs to be queried
-                                            // from the actual hardware configuration
-                }
-            }
+//X             QStringList groups = m_config->groupList();
+//X             foreach (QString group, groups) {
+//X                 if (group.startsWith("AudioOutputDevice_")) {
+//X                     const int index = group.right(group.size() - 18/*strlen("AudioOutputDevice_") */).toInt();
+//X                     if (index >= nextIndex) {
+//X                         nextIndex = index + 1;
+//X                     }
+//X                     KConfigGroup config(m_config, group);
+//X                     m_audioOutputInfos << AudioOutputInfo(index,
+//X                             config.readEntry("initialPreference", 0),
+//X                             config.readEntry("name", QString()),
+//X                             config.readEntry("description", QString()),
+//X                             config.readEntry("icon", QString()),
+//X                             config.readEntry("driver", QByteArray()),
+//X                             QStringList(), QString()); // the device list can change and needs to be queried
+//X                                             // from the actual hardware configuration
+//X                 }
+//X             }
 
             // This will list the audio drivers, not the actual devices.
             const char *const *outputPlugins = xine_list_audio_output_plugins(xine());
             for (int i = 0; outputPlugins[i]; ++i) {
                 kDebug(610) << "outputPlugin: " << outputPlugins[i];
                 if (0 == strcmp(outputPlugins[i], "alsa")) {
+                    if (m_useOss == XineEngine::Unknown) {
+                        m_useOss = KConfigGroup(m_config, "Settings").readEntry("showOssDevices", false) ? XineEngine::True : XineEngine::False;
+                        if (m_useOss == XineEngine::False) {
+                            // remove all OSS devices
+                            typedef QList<AudioOutputInfo>::iterator Iterator;
+                            const Iterator end = m_audioOutputInfos.end();
+                            Iterator it = m_audioOutputInfos.begin();
+                            while (it != end) {
+                                if (it->driver == "oss") {
+                                    it = m_audioOutputInfos.erase(it);
+                                } else {
+                                    ++it;
+                                }
+                            }
+                        }
+                    }
+
                     QList<AudioDevice> alsaDevices = AudioDeviceEnumerator::availablePlaybackDevices();
-                    foreach (AudioDevice dev, alsaDevices) {
+                    foreach (const AudioDevice &dev, alsaDevices) {
                         if (dev.driver() == Solid::AudioInterface::Alsa) {
-                            addAudioOutput(dev, QLatin1String("alsa"));
+                            addAudioOutput(dev, "alsa");
                         }
                     }
                 } else if (0 == strcmp(outputPlugins[i], "none") || 0 == strcmp(outputPlugins[i], "file")) {
@@ -428,35 +542,45 @@ namespace Xine
                 } else if (0 == strcmp(outputPlugins[i], "oss")) {
                     if (m_useOss) {
                         QList<AudioDevice> audioDevices = AudioDeviceEnumerator::availablePlaybackDevices();
-                        foreach (AudioDevice dev, audioDevices) {
+                        foreach (const AudioDevice &dev, audioDevices) {
                             if (dev.driver() == Solid::AudioInterface::OpenSoundSystem) {
-                                addAudioOutput(dev, QLatin1String("oss"));
+                                addAudioOutput(dev, "oss");
                             }
                         }
                     }
                 } else if (0 == strcmp(outputPlugins[i], "jack")) {
-                    addAudioOutput(nextIndex++, i18n("Jack Audio Connection Kit"),
+                    addAudioOutput(nextIndex++, -10, i18n("Jack Audio Connection Kit"),
                             i18n("<html><p>JACK is a low-latency audio server. It can connect a number "
                                 "of different applications to an audio device, as well as allowing "
                                 "them to share audio between themselves.</p>"
                                 "<p>JACK was designed from the ground up for professional audio "
                                 "work, and its design focuses on two key areas: synchronous "
                                 "execution of all clients, and low latency operation.</p></html>"),
-                            /*icon name*/"audio-input-line", outputPlugins[i], QStringList());
+                            /*icon name */"audio-backend-jack", outputPlugins[i], QStringList(),
+                            QString());
                 } else if (0 == strcmp(outputPlugins[i], "arts")) {
-                    addAudioOutput(nextIndex++, i18n("aRts"),
+                    addAudioOutput(nextIndex++, -100, i18n("aRts"),
                             i18n("<html><p>aRts is the old soundserver and media framework that was used "
                                 "in KDE2 and KDE3. Its use is discuraged.</p></html>"),
-                            /*icon name*/"arts", outputPlugins[i], QStringList());
-                } else {
-                    addAudioOutput(nextIndex++, outputPlugins[i],
+                            /*icon name */"audio-backend-arts", outputPlugins[i], QStringList(), QString());
+                } else if (0 == strcmp(outputPlugins[i], "pulseaudio")) {
+                    addAudioOutput(nextIndex++, 10, i18n("PulseAudio"),
                             xine_get_audio_driver_plugin_description(xine(), outputPlugins[i]),
-                            /*icon name*/outputPlugins[i], outputPlugins[i], QStringList());
+                            /*icon name */"audio-backend-pulseaudio", outputPlugins[i], QStringList(), QString());
+                } else if (0 == strcmp(outputPlugins[i], "esd")) {
+                    addAudioOutput(nextIndex++, 10, i18n("Esound (ESD)"),
+                            xine_get_audio_driver_plugin_description(xine(), outputPlugins[i]),
+                            /*icon name */"audio-backend-esd", outputPlugins[i], QStringList(), QString());
+                } else {
+                    addAudioOutput(nextIndex++, -20, outputPlugins[i],
+                            xine_get_audio_driver_plugin_description(xine(), outputPlugins[i]),
+                            /*icon name */outputPlugins[i], outputPlugins[i], QStringList(),
+                            QString());
                 }
             }
 
             // now m_audioOutputInfos holds all devices this computer has ever seen
-            foreach (AudioOutputInfo info, m_audioOutputInfos) {
+            foreach (const AudioOutputInfo &info, m_audioOutputInfos) {
                 kDebug(610) << info.index << info.name << info.driver << info.devices;
             }
         }
@@ -470,26 +594,26 @@ namespace Xine
         }
         const char *const *outputPlugins = xine_list_audio_output_plugins(XineEngine::xine());
         switch (dev.driver()) {
-            case Solid::AudioInterface::Alsa:
+        case Solid::AudioInterface::Alsa:
+            for (int i = 0; outputPlugins[i]; ++i) {
+                if (0 == strcmp(outputPlugins[i], "alsa")) {
+                    s_instance->addAudioOutput(dev, "alsa");
+                    signalTimer.start();
+                }
+            }
+            break;
+        case Solid::AudioInterface::OpenSoundSystem:
+            if (s_instance->m_useOss) {
                 for (int i = 0; outputPlugins[i]; ++i) {
-                    if (0 == strcmp(outputPlugins[i], "alsa")) {
-                        s_instance->addAudioOutput(dev, QLatin1String("alsa"));
+                    if (0 == strcmp(outputPlugins[i], "oss")) {
+                        s_instance->addAudioOutput(dev, "oss");
                         signalTimer.start();
                     }
                 }
-                break;
-            case Solid::AudioInterface::OpenSoundSystem:
-                if (s_instance->m_useOss) {
-                    for (int i = 0; outputPlugins[i]; ++i) {
-                        if (0 == strcmp(outputPlugins[i], "oss")) {
-                            s_instance->addAudioOutput(dev, QLatin1String("oss"));
-                            signalTimer.start();
-                        }
-                    }
-                }
-                break;
-            case Solid::AudioInterface::UnknownAudioDriver:
-                break;
+            }
+            break;
+        case Solid::AudioInterface::UnknownAudioDriver:
+            break;
         }
     }
 
@@ -499,31 +623,20 @@ namespace Xine
         if (!dev.isPlaybackDevice()) {
             return;
         }
-        QString driver;
-        QString postfix;
-        switch (dev.driver()) {
-            case Solid::AudioInterface::Alsa:
-                driver = "alsa";
-                if (s_instance->m_useOss) {
-                    postfix = QLatin1String(" (ALSA)");
-                }
-                break;
-            case Solid::AudioInterface::OpenSoundSystem:
-                driver = "oss";
-                postfix = QLatin1String(" (OSS)");
-                break;
-            case Solid::AudioInterface::UnknownAudioDriver:
-                break;
-        }
-        XineEngine::AudioOutputInfo info(dev.index(), dev.cardName() + postfix, QString(), dev.iconName(),
-                driver, dev.deviceIds());
-        if (s_instance->m_audioOutputInfos.removeAll(info)) {
-            s_instance->m_audioOutputInfos << info; // now the device is listed as not available
-            signalTimer.start();
-        } else {
-            kDebug(610) << "told to remove " << dev.cardName() + postfix <<
+        QByteArray driver;
+        XineEngine::AudioOutputInfo info(dev.index(), 0, dev.cardName(), QString(), dev.iconName(),
+                driver, dev.deviceIds(), QString());
+        const int indexOfInfo = s_instance->m_audioOutputInfos.indexOf(info);
+        if (indexOfInfo < 0) {
+            kDebug(610) << "told to remove " << dev.cardName() <<
                 " with driver " << driver << " but the device was not present in m_audioOutputInfos";
+            return;
         }
+        const XineEngine::AudioOutputInfo oldInfo = s_instance->m_audioOutputInfos.takeAt(indexOfInfo);
+        Q_ASSERT(!s_instance->m_audioOutputInfos.contains(info));
+        info.initialPreference = oldInfo.initialPreference;
+        s_instance->m_audioOutputInfos << info; // now the device is listed as not available
+        signalTimer.start();
     }
 } // namespace Xine
 } // namespace Phonon
